Struct aws_sdk_worklink::client::fluent_builders::AssociateDomain
source · pub struct AssociateDomain { /* private fields */ }Expand description
Fluent builder constructing a request to AssociateDomain.
Specifies a domain to be associated to Amazon WorkLink.
Implementations
sourceimpl AssociateDomain
impl AssociateDomain
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<AssociateDomain, AwsResponseRetryClassifier>, SdkError<AssociateDomainError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<AssociateDomain, AwsResponseRetryClassifier>, SdkError<AssociateDomainError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(
self
) -> Result<AssociateDomainOutput, SdkError<AssociateDomainError>>
pub async fn send(
self
) -> Result<AssociateDomainOutput, SdkError<AssociateDomainError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn fleet_arn(self, input: impl Into<String>) -> Self
pub fn fleet_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the fleet.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the fleet.
sourcepub fn domain_name(self, input: impl Into<String>) -> Self
pub fn domain_name(self, input: impl Into<String>) -> Self
The fully qualified domain name (FQDN).
sourcepub fn set_domain_name(self, input: Option<String>) -> Self
pub fn set_domain_name(self, input: Option<String>) -> Self
The fully qualified domain name (FQDN).
sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
The name to display.
sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
The name to display.
sourcepub fn acm_certificate_arn(self, input: impl Into<String>) -> Self
pub fn acm_certificate_arn(self, input: impl Into<String>) -> Self
The ARN of an issued ACM certificate that is valid for the domain being associated.
sourcepub fn set_acm_certificate_arn(self, input: Option<String>) -> Self
pub fn set_acm_certificate_arn(self, input: Option<String>) -> Self
The ARN of an issued ACM certificate that is valid for the domain being associated.