pub struct AssociateWebsiteAuthorizationProvider { /* private fields */ }Amazon WorkLink is no longer supported. This will be removed in a future version of the SDK.
Fluent builder constructing a request to AssociateWebsiteAuthorizationProvider.
Associates a website authorization provider with a specified fleet. This is used to authorize users against associated websites in the company network.
Implementations
sourceimpl AssociateWebsiteAuthorizationProvider
impl AssociateWebsiteAuthorizationProvider
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<AssociateWebsiteAuthorizationProvider, AwsResponseRetryClassifier>, SdkError<AssociateWebsiteAuthorizationProviderError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<AssociateWebsiteAuthorizationProvider, AwsResponseRetryClassifier>, SdkError<AssociateWebsiteAuthorizationProviderError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(
self
) -> Result<AssociateWebsiteAuthorizationProviderOutput, SdkError<AssociateWebsiteAuthorizationProviderError>>
pub async fn send(
self
) -> Result<AssociateWebsiteAuthorizationProviderOutput, SdkError<AssociateWebsiteAuthorizationProviderError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The ARN of the fleet.
The authorization provider type.
The authorization provider type.
sourcepub fn domain_name(self, input: impl Into<String>) -> Self
pub fn domain_name(self, input: impl Into<String>) -> Self
The domain name of the authorization provider. This applies only to SAML-based authorization providers.
sourcepub fn set_domain_name(self, input: Option<String>) -> Self
pub fn set_domain_name(self, input: Option<String>) -> Self
The domain name of the authorization provider. This applies only to SAML-based authorization providers.