Struct aws_sdk_worklink::client::fluent_builders::CreateFleet
source · pub struct CreateFleet { /* private fields */ }Expand description
Fluent builder constructing a request to CreateFleet.
Creates a fleet. A fleet consists of resources and the configuration that delivers associated websites to authorized users who download and set up the Amazon WorkLink app.
Implementations
sourceimpl CreateFleet
impl CreateFleet
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<CreateFleet, AwsResponseRetryClassifier>, SdkError<CreateFleetError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<CreateFleet, AwsResponseRetryClassifier>, SdkError<CreateFleetError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(self) -> Result<CreateFleetOutput, SdkError<CreateFleetError>>
pub async fn send(self) -> Result<CreateFleetOutput, SdkError<CreateFleetError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn fleet_name(self, input: impl Into<String>) -> Self
pub fn fleet_name(self, input: impl Into<String>) -> Self
A unique name for the fleet.
sourcepub fn set_fleet_name(self, input: Option<String>) -> Self
pub fn set_fleet_name(self, input: Option<String>) -> Self
A unique name for the fleet.
sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
The fleet name to display.
sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
The fleet name to display.
sourcepub fn optimize_for_end_user_location(self, input: bool) -> Self
pub fn optimize_for_end_user_location(self, input: bool) -> Self
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
sourcepub fn set_optimize_for_end_user_location(self, input: Option<bool>) -> Self
pub fn set_optimize_for_end_user_location(self, input: Option<bool>) -> Self
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
Adds a key-value pair to Tags.
To override the contents of this collection use set_tags.
The tags to add to the resource. A tag is a key-value pair.
The tags to add to the resource. A tag is a key-value pair.