Struct aws_sdk_worklink::client::fluent_builders::DescribeDevice
source · pub struct DescribeDevice { /* private fields */ }👎Deprecated: Amazon WorkLink is no longer supported. This will be removed in a future version of the SDK.
Fluent builder constructing a request to DescribeDevice.
Provides information about a user's device.
Implementations
sourceimpl DescribeDevice
impl DescribeDevice
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<DescribeDevice, AwsResponseRetryClassifier>, SdkError<DescribeDeviceError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<DescribeDevice, AwsResponseRetryClassifier>, SdkError<DescribeDeviceError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(
self
) -> Result<DescribeDeviceOutput, SdkError<DescribeDeviceError>>
pub async fn send(
self
) -> Result<DescribeDeviceOutput, SdkError<DescribeDeviceError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The ARN of the fleet.
sourcepub fn device_id(self, input: impl Into<String>) -> Self
pub fn device_id(self, input: impl Into<String>) -> Self
A unique identifier for a registered user's device.
sourcepub fn set_device_id(self, input: Option<String>) -> Self
pub fn set_device_id(self, input: Option<String>) -> Self
A unique identifier for a registered user's device.