pub struct DescribeDevicePolicyConfiguration { /* private fields */ }👎Deprecated: Amazon WorkLink is no longer supported. This will be removed in a future version of the SDK.
Fluent builder constructing a request to DescribeDevicePolicyConfiguration.
Describes the device policy configuration for the specified fleet.
Implementations
sourceimpl DescribeDevicePolicyConfiguration
impl DescribeDevicePolicyConfiguration
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<DescribeDevicePolicyConfiguration, AwsResponseRetryClassifier>, SdkError<DescribeDevicePolicyConfigurationError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<DescribeDevicePolicyConfiguration, AwsResponseRetryClassifier>, SdkError<DescribeDevicePolicyConfigurationError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(
self
) -> Result<DescribeDevicePolicyConfigurationOutput, SdkError<DescribeDevicePolicyConfigurationError>>
pub async fn send(
self
) -> Result<DescribeDevicePolicyConfigurationOutput, SdkError<DescribeDevicePolicyConfigurationError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The ARN of the fleet.