Struct aws_sdk_worklink::client::fluent_builders::DescribeDomain
source · pub struct DescribeDomain { /* private fields */ }👎Deprecated: Amazon WorkLink is no longer supported. This will be removed in a future version of the SDK.
Fluent builder constructing a request to DescribeDomain.
Provides information about the domain.
Implementations
sourceimpl DescribeDomain
impl DescribeDomain
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<DescribeDomain, AwsResponseRetryClassifier>, SdkError<DescribeDomainError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<DescribeDomain, AwsResponseRetryClassifier>, SdkError<DescribeDomainError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(
self
) -> Result<DescribeDomainOutput, SdkError<DescribeDomainError>>
pub async fn send(
self
) -> Result<DescribeDomainOutput, SdkError<DescribeDomainError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The ARN of the fleet.
sourcepub fn domain_name(self, input: impl Into<String>) -> Self
pub fn domain_name(self, input: impl Into<String>) -> Self
The name of the domain.
sourcepub fn set_domain_name(self, input: Option<String>) -> Self
pub fn set_domain_name(self, input: Option<String>) -> Self
The name of the domain.