pub struct DisassociateWebsiteAuthorizationProvider { /* private fields */ }Expand description
Fluent builder constructing a request to DisassociateWebsiteAuthorizationProvider.
Disassociates a website authorization provider from a specified fleet. After the disassociation, users can't load any associated websites that require this authorization provider.
Implementations
sourceimpl DisassociateWebsiteAuthorizationProvider
impl DisassociateWebsiteAuthorizationProvider
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<DisassociateWebsiteAuthorizationProvider, AwsResponseRetryClassifier>, SdkError<DisassociateWebsiteAuthorizationProviderError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<DisassociateWebsiteAuthorizationProvider, AwsResponseRetryClassifier>, SdkError<DisassociateWebsiteAuthorizationProviderError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(
self
) -> Result<DisassociateWebsiteAuthorizationProviderOutput, SdkError<DisassociateWebsiteAuthorizationProviderError>>
pub async fn send(
self
) -> Result<DisassociateWebsiteAuthorizationProviderOutput, SdkError<DisassociateWebsiteAuthorizationProviderError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The ARN of the fleet.
A unique identifier for the authorization provider.
A unique identifier for the authorization provider.