Struct aws_sdk_worklink::client::fluent_builders::ListDevices
source · [−]pub struct ListDevices<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to ListDevices.
Retrieves a list of devices registered with the specified fleet.
Implementations
impl<C, M, R> ListDevices<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> ListDevices<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(self) -> Result<ListDevicesOutput, SdkError<ListDevicesError>> where
R::Policy: SmithyRetryPolicy<ListDevicesInputOperationOutputAlias, ListDevicesOutput, ListDevicesError, ListDevicesInputOperationRetryAlias>,
pub async fn send(self) -> Result<ListDevicesOutput, SdkError<ListDevicesError>> where
R::Policy: SmithyRetryPolicy<ListDevicesInputOperationOutputAlias, ListDevicesOutput, ListDevicesError, ListDevicesInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Create a paginator for this request
Paginators are used by calling send().await which returns a Stream.
The ARN of the fleet.
The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
The maximum number of results to be included in the next page.
The maximum number of results to be included in the next page.