Struct aws_sdk_worklink::client::fluent_builders::RevokeDomainAccess
source · [−]pub struct RevokeDomainAccess<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to RevokeDomainAccess.
Moves a domain to INACTIVE status if it was in the ACTIVE status.
Implementations
impl<C, M, R> RevokeDomainAccess<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> RevokeDomainAccess<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<RevokeDomainAccessOutput, SdkError<RevokeDomainAccessError>> where
R::Policy: SmithyRetryPolicy<RevokeDomainAccessInputOperationOutputAlias, RevokeDomainAccessOutput, RevokeDomainAccessError, RevokeDomainAccessInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<RevokeDomainAccessOutput, SdkError<RevokeDomainAccessError>> where
R::Policy: SmithyRetryPolicy<RevokeDomainAccessInputOperationOutputAlias, RevokeDomainAccessOutput, RevokeDomainAccessError, RevokeDomainAccessInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ARN of the fleet.
The name of the domain.
The name of the domain.