Struct aws_sdk_worklink::client::fluent_builders::SignOutUser
source · pub struct SignOutUser { /* private fields */ }👎Deprecated: Amazon WorkLink is no longer supported. This will be removed in a future version of the SDK.
Fluent builder constructing a request to SignOutUser.
Signs the user out from all of their devices. The user can sign in again if they have valid credentials.
Implementations
sourceimpl SignOutUser
impl SignOutUser
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<SignOutUser, AwsResponseRetryClassifier>, SdkError<SignOutUserError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<SignOutUser, AwsResponseRetryClassifier>, SdkError<SignOutUserError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(self) -> Result<SignOutUserOutput, SdkError<SignOutUserError>>
pub async fn send(self) -> Result<SignOutUserOutput, SdkError<SignOutUserError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The ARN of the fleet.
sourcepub fn set_username(self, input: Option<String>) -> Self
pub fn set_username(self, input: Option<String>) -> Self
The name of the user.