pub struct UpdateAuditStreamConfiguration { /* private fields */ }👎Deprecated: Amazon WorkLink is no longer supported. This will be removed in a future version of the SDK.
Fluent builder constructing a request to UpdateAuditStreamConfiguration.
Updates the audit stream configuration for the fleet.
Implementations
sourceimpl UpdateAuditStreamConfiguration
impl UpdateAuditStreamConfiguration
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<UpdateAuditStreamConfiguration, AwsResponseRetryClassifier>, SdkError<UpdateAuditStreamConfigurationError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<UpdateAuditStreamConfiguration, AwsResponseRetryClassifier>, SdkError<UpdateAuditStreamConfigurationError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(
self
) -> Result<UpdateAuditStreamConfigurationOutput, SdkError<UpdateAuditStreamConfigurationError>>
pub async fn send(
self
) -> Result<UpdateAuditStreamConfigurationOutput, SdkError<UpdateAuditStreamConfigurationError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The ARN of the fleet.
sourcepub fn audit_stream_arn(self, input: impl Into<String>) -> Self
pub fn audit_stream_arn(self, input: impl Into<String>) -> Self
The ARN of the Amazon Kinesis data stream that receives the audit events.
sourcepub fn set_audit_stream_arn(self, input: Option<String>) -> Self
pub fn set_audit_stream_arn(self, input: Option<String>) -> Self
The ARN of the Amazon Kinesis data stream that receives the audit events.