pub struct UpdateCompanyNetworkConfiguration { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateCompanyNetworkConfiguration.
Updates the company network configuration for the fleet.
Implementations
sourceimpl UpdateCompanyNetworkConfiguration
impl UpdateCompanyNetworkConfiguration
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<UpdateCompanyNetworkConfiguration, AwsResponseRetryClassifier>, SdkError<UpdateCompanyNetworkConfigurationError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<UpdateCompanyNetworkConfiguration, AwsResponseRetryClassifier>, SdkError<UpdateCompanyNetworkConfigurationError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(
self
) -> Result<UpdateCompanyNetworkConfigurationOutput, SdkError<UpdateCompanyNetworkConfigurationError>>
pub async fn send(
self
) -> Result<UpdateCompanyNetworkConfigurationOutput, SdkError<UpdateCompanyNetworkConfigurationError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The ARN of the fleet.
sourcepub fn vpc_id(self, input: impl Into<String>) -> Self
pub fn vpc_id(self, input: impl Into<String>) -> Self
The VPC with connectivity to associated websites.
sourcepub fn set_vpc_id(self, input: Option<String>) -> Self
pub fn set_vpc_id(self, input: Option<String>) -> Self
The VPC with connectivity to associated websites.
sourcepub fn subnet_ids(self, input: impl Into<String>) -> Self
pub fn subnet_ids(self, input: impl Into<String>) -> Self
Appends an item to SubnetIds.
To override the contents of this collection use set_subnet_ids.
The subnets used for X-ENI connections from Amazon WorkLink rendering containers.
sourcepub fn set_subnet_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_subnet_ids(self, input: Option<Vec<String>>) -> Self
The subnets used for X-ENI connections from Amazon WorkLink rendering containers.
sourcepub fn security_group_ids(self, input: impl Into<String>) -> Self
pub fn security_group_ids(self, input: impl Into<String>) -> Self
Appends an item to SecurityGroupIds.
To override the contents of this collection use set_security_group_ids.
The security groups associated with access to the provided subnets.
sourcepub fn set_security_group_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_security_group_ids(self, input: Option<Vec<String>>) -> Self
The security groups associated with access to the provided subnets.