pub struct UpdateDevicePolicyConfiguration { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateDevicePolicyConfiguration.
Updates the device policy configuration for the fleet.
Implementations
sourceimpl UpdateDevicePolicyConfiguration
impl UpdateDevicePolicyConfiguration
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<UpdateDevicePolicyConfiguration, AwsResponseRetryClassifier>, SdkError<UpdateDevicePolicyConfigurationError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<UpdateDevicePolicyConfiguration, AwsResponseRetryClassifier>, SdkError<UpdateDevicePolicyConfigurationError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(
self
) -> Result<UpdateDevicePolicyConfigurationOutput, SdkError<UpdateDevicePolicyConfigurationError>>
pub async fn send(
self
) -> Result<UpdateDevicePolicyConfigurationOutput, SdkError<UpdateDevicePolicyConfigurationError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The ARN of the fleet.
sourcepub fn device_ca_certificate(self, input: impl Into<String>) -> Self
pub fn device_ca_certificate(self, input: impl Into<String>) -> Self
The certificate chain, including intermediate certificates and the root certificate authority certificate used to issue device certificates.
sourcepub fn set_device_ca_certificate(self, input: Option<String>) -> Self
pub fn set_device_ca_certificate(self, input: Option<String>) -> Self
The certificate chain, including intermediate certificates and the root certificate authority certificate used to issue device certificates.