Struct aws_sdk_worklink::client::fluent_builders::UpdateDomainMetadata
source ·
[−]pub struct UpdateDomainMetadata<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to UpdateDomainMetadata.
Updates domain metadata, such as DisplayName.
Implementations
impl<C, M, R> UpdateDomainMetadata<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> UpdateDomainMetadata<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<UpdateDomainMetadataOutput, SdkError<UpdateDomainMetadataError>> where
R::Policy: SmithyRetryPolicy<UpdateDomainMetadataInputOperationOutputAlias, UpdateDomainMetadataOutput, UpdateDomainMetadataError, UpdateDomainMetadataInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<UpdateDomainMetadataOutput, SdkError<UpdateDomainMetadataError>> where
R::Policy: SmithyRetryPolicy<UpdateDomainMetadataInputOperationOutputAlias, UpdateDomainMetadataOutput, UpdateDomainMetadataError, UpdateDomainMetadataInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ARN of the fleet.
The name of the domain.
The name of the domain.
The name to display.
The name to display.