pub struct UpdateIdentityProviderConfiguration { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateIdentityProviderConfiguration.
Updates the identity provider configuration for the fleet.
Implementations
sourceimpl UpdateIdentityProviderConfiguration
impl UpdateIdentityProviderConfiguration
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<UpdateIdentityProviderConfiguration, AwsResponseRetryClassifier>, SdkError<UpdateIdentityProviderConfigurationError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<UpdateIdentityProviderConfiguration, AwsResponseRetryClassifier>, SdkError<UpdateIdentityProviderConfigurationError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(
self
) -> Result<UpdateIdentityProviderConfigurationOutput, SdkError<UpdateIdentityProviderConfigurationError>>
pub async fn send(
self
) -> Result<UpdateIdentityProviderConfigurationOutput, SdkError<UpdateIdentityProviderConfigurationError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The ARN of the fleet.
sourcepub fn identity_provider_type(self, input: IdentityProviderType) -> Self
pub fn identity_provider_type(self, input: IdentityProviderType) -> Self
The type of identity provider.
sourcepub fn set_identity_provider_type(
self,
input: Option<IdentityProviderType>
) -> Self
pub fn set_identity_provider_type(
self,
input: Option<IdentityProviderType>
) -> Self
The type of identity provider.
sourcepub fn identity_provider_saml_metadata(self, input: impl Into<String>) -> Self
pub fn identity_provider_saml_metadata(self, input: impl Into<String>) -> Self
The SAML metadata document provided by the customer’s identity provider. The existing IdentityProviderSamlMetadata is unset if null is passed.
sourcepub fn set_identity_provider_saml_metadata(self, input: Option<String>) -> Self
pub fn set_identity_provider_saml_metadata(self, input: Option<String>) -> Self
The SAML metadata document provided by the customer’s identity provider. The existing IdentityProviderSamlMetadata is unset if null is passed.