Struct aws_sdk_worklink::client::Client
source · [−]pub struct Client<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* private fields */ }Expand description
Client for Amazon WorkLink
Client for invoking operations on Amazon WorkLink. Each operation on Amazon WorkLink is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Examples
Constructing a client and invoking an operation
// create a shared configuration. This can be used & shared between multiple service clients.
let shared_config = aws_config::load_from_env().await;
let client = aws_sdk_worklink::Client::new(&shared_config);
// invoke an operation
/* let rsp = client
.<operation_name>().
.<param>("some value")
.send().await; */Constructing a client with custom configuration
use aws_config::RetryConfig;
let shared_config = aws_config::load_from_env().await;
let config = aws_sdk_worklink::config::Builder::from(&shared_config)
.retry_config(RetryConfig::disabled())
.build();
let client = aws_sdk_worklink::Client::from_conf(config);Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the AssociateDomain operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The Amazon Resource Name (ARN) of the fleet.
domain_name(impl Into<String>)/set_domain_name(Option<String>):The fully qualified domain name (FQDN).
display_name(impl Into<String>)/set_display_name(Option<String>):The name to display.
acm_certificate_arn(impl Into<String>)/set_acm_certificate_arn(Option<String>):The ARN of an issued ACM certificate that is valid for the domain being associated.
- On success, responds with
AssociateDomainOutput - On failure, responds with
SdkError<AssociateDomainError>
Constructs a fluent builder for the AssociateWebsiteAuthorizationProvider operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
authorization_provider_type(AuthorizationProviderType)/set_authorization_provider_type(Option<AuthorizationProviderType>):The authorization provider type.
domain_name(impl Into<String>)/set_domain_name(Option<String>):The domain name of the authorization provider. This applies only to SAML-based authorization providers.
- On success, responds with
AssociateWebsiteAuthorizationProviderOutputwith field(s):authorization_provider_id(Option<String>):A unique identifier for the authorization provider.
- On failure, responds with
SdkError<AssociateWebsiteAuthorizationProviderError>
Constructs a fluent builder for the AssociateWebsiteCertificateAuthority operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
certificate(impl Into<String>)/set_certificate(Option<String>):The root certificate of the CA.
display_name(impl Into<String>)/set_display_name(Option<String>):The certificate name to display.
- On success, responds with
AssociateWebsiteCertificateAuthorityOutputwith field(s):website_ca_id(Option<String>):A unique identifier for the CA.
- On failure, responds with
SdkError<AssociateWebsiteCertificateAuthorityError>
Constructs a fluent builder for the CreateFleet operation.
- The fluent builder is configurable:
fleet_name(impl Into<String>)/set_fleet_name(Option<String>):A unique name for the fleet.
display_name(impl Into<String>)/set_display_name(Option<String>):The fleet name to display.
optimize_for_end_user_location(bool)/set_optimize_for_end_user_location(Option<bool>):The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
tags(HashMap<String, String>)/set_tags(Option<HashMap<String, String>>):The tags to add to the resource. A tag is a key-value pair.
- On success, responds with
CreateFleetOutputwith field(s):fleet_arn(Option<String>):The Amazon Resource Name (ARN) of the fleet.
- On failure, responds with
SdkError<CreateFleetError>
Constructs a fluent builder for the DeleteFleet operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
- On success, responds with
DeleteFleetOutput - On failure, responds with
SdkError<DeleteFleetError>
pub fn describe_audit_stream_configuration(
&self
) -> DescribeAuditStreamConfiguration<C, M, R>
pub fn describe_audit_stream_configuration(
&self
) -> DescribeAuditStreamConfiguration<C, M, R>
Constructs a fluent builder for the DescribeAuditStreamConfiguration operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
- On success, responds with
DescribeAuditStreamConfigurationOutputwith field(s):audit_stream_arn(Option<String>):The ARN of the Amazon Kinesis data stream that will receive the audit events.
- On failure, responds with
SdkError<DescribeAuditStreamConfigurationError>
pub fn describe_company_network_configuration(
&self
) -> DescribeCompanyNetworkConfiguration<C, M, R>
pub fn describe_company_network_configuration(
&self
) -> DescribeCompanyNetworkConfiguration<C, M, R>
Constructs a fluent builder for the DescribeCompanyNetworkConfiguration operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
- On success, responds with
DescribeCompanyNetworkConfigurationOutputwith field(s):vpc_id(Option<String>):The VPC with connectivity to associated websites.
subnet_ids(Option<Vec<String>>):The subnets used for X-ENI connections from Amazon WorkLink rendering containers.
security_group_ids(Option<Vec<String>>):The security groups associated with access to the provided subnets.
- On failure, responds with
SdkError<DescribeCompanyNetworkConfigurationError>
Constructs a fluent builder for the DescribeDevice operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
device_id(impl Into<String>)/set_device_id(Option<String>):A unique identifier for a registered user’s device.
- On success, responds with
DescribeDeviceOutputwith field(s):status(Option<DeviceStatus>):The current state of the device.
model(Option<String>):The model of the device.
manufacturer(Option<String>):The manufacturer of the device.
operating_system(Option<String>):The operating system of the device.
operating_system_version(Option<String>):The operating system version of the device.
patch_level(Option<String>):The operating system patch level of the device.
first_accessed_time(Option<DateTime>):The date that the device first signed in to Amazon WorkLink.
last_accessed_time(Option<DateTime>):The date that the device last accessed Amazon WorkLink.
username(Option<String>):The user name associated with the device.
- On failure, responds with
SdkError<DescribeDeviceError>
pub fn describe_device_policy_configuration(
&self
) -> DescribeDevicePolicyConfiguration<C, M, R>
pub fn describe_device_policy_configuration(
&self
) -> DescribeDevicePolicyConfiguration<C, M, R>
Constructs a fluent builder for the DescribeDevicePolicyConfiguration operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
- On success, responds with
DescribeDevicePolicyConfigurationOutputwith field(s):device_ca_certificate(Option<String>):The certificate chain, including intermediate certificates and the root certificate authority certificate used to issue device certificates.
- On failure, responds with
SdkError<DescribeDevicePolicyConfigurationError>
Constructs a fluent builder for the DescribeDomain operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
domain_name(impl Into<String>)/set_domain_name(Option<String>):The name of the domain.
- On success, responds with
DescribeDomainOutputwith field(s):domain_name(Option<String>):The name of the domain.
display_name(Option<String>):The name to display.
created_time(Option<DateTime>):The time that the domain was added.
domain_status(Option<DomainStatus>):The current state for the domain.
acm_certificate_arn(Option<String>):The ARN of an issued ACM certificate that is valid for the domain being associated.
- On failure, responds with
SdkError<DescribeDomainError>
Constructs a fluent builder for the DescribeFleetMetadata operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The Amazon Resource Name (ARN) of the fleet.
- On success, responds with
DescribeFleetMetadataOutputwith field(s):created_time(Option<DateTime>):The time that the fleet was created.
last_updated_time(Option<DateTime>):The time that the fleet was last updated.
fleet_name(Option<String>):The name of the fleet.
display_name(Option<String>):The name to display.
optimize_for_end_user_location(Option<bool>):The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
company_code(Option<String>):The identifier used by users to sign in to the Amazon WorkLink app.
fleet_status(Option<FleetStatus>):The current state of the fleet.
tags(Option<HashMap<String, String>>):The tags attached to the resource. A tag is a key-value pair.
- On failure, responds with
SdkError<DescribeFleetMetadataError>
pub fn describe_identity_provider_configuration(
&self
) -> DescribeIdentityProviderConfiguration<C, M, R>
pub fn describe_identity_provider_configuration(
&self
) -> DescribeIdentityProviderConfiguration<C, M, R>
Constructs a fluent builder for the DescribeIdentityProviderConfiguration operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
- On success, responds with
DescribeIdentityProviderConfigurationOutputwith field(s):identity_provider_type(Option<IdentityProviderType>):The type of identity provider.
service_provider_saml_metadata(Option<String>):The SAML metadata document uploaded to the user’s identity provider.
identity_provider_saml_metadata(Option<String>):The SAML metadata document provided by the user’s identity provider.
- On failure, responds with
SdkError<DescribeIdentityProviderConfigurationError>
Constructs a fluent builder for the DescribeWebsiteCertificateAuthority operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
website_ca_id(impl Into<String>)/set_website_ca_id(Option<String>):A unique identifier for the certificate authority.
- On success, responds with
DescribeWebsiteCertificateAuthorityOutputwith field(s):certificate(Option<String>):The root certificate of the certificate authority.
created_time(Option<DateTime>):The time that the certificate authority was added.
display_name(Option<String>):The certificate name to display.
- On failure, responds with
SdkError<DescribeWebsiteCertificateAuthorityError>
Constructs a fluent builder for the DisassociateDomain operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
domain_name(impl Into<String>)/set_domain_name(Option<String>):The name of the domain.
- On success, responds with
DisassociateDomainOutput - On failure, responds with
SdkError<DisassociateDomainError>
Constructs a fluent builder for the DisassociateWebsiteAuthorizationProvider operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
authorization_provider_id(impl Into<String>)/set_authorization_provider_id(Option<String>):A unique identifier for the authorization provider.
- On success, responds with
DisassociateWebsiteAuthorizationProviderOutput - On failure, responds with
SdkError<DisassociateWebsiteAuthorizationProviderError>
Constructs a fluent builder for the DisassociateWebsiteCertificateAuthority operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
website_ca_id(impl Into<String>)/set_website_ca_id(Option<String>):A unique identifier for the CA.
- On success, responds with
DisassociateWebsiteCertificateAuthorityOutput - On failure, responds with
SdkError<DisassociateWebsiteCertificateAuthorityError>
Constructs a fluent builder for the ListDevices operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
next_token(impl Into<String>)/set_next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
max_results(i32)/set_max_results(Option<i32>):The maximum number of results to be included in the next page.
- On success, responds with
ListDevicesOutputwith field(s):devices(Option<Vec<DeviceSummary>>):Information about the devices.
next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation. If there are no more pages, this value is null.
- On failure, responds with
SdkError<ListDevicesError>
Constructs a fluent builder for the ListDomains operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
next_token(impl Into<String>)/set_next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
max_results(i32)/set_max_results(Option<i32>):The maximum number of results to be included in the next page.
- On success, responds with
ListDomainsOutputwith field(s):domains(Option<Vec<DomainSummary>>):Information about the domains.
next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation. If there are no more pages, this value is null.
- On failure, responds with
SdkError<ListDomainsError>
Constructs a fluent builder for the ListFleets operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
max_results(i32)/set_max_results(Option<i32>):The maximum number of results to be included in the next page.
- On success, responds with
ListFleetsOutputwith field(s):fleet_summary_list(Option<Vec<FleetSummary>>):The summary list of the fleets.
next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation. If there are no more pages, this value is null.
- On failure, responds with
SdkError<ListFleetsError>
Constructs a fluent builder for the ListTagsForResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The Amazon Resource Name (ARN) of the fleet.
- On success, responds with
ListTagsForResourceOutputwith field(s):tags(Option<HashMap<String, String>>):The tags attached to the resource. A tag is a key-value pair.
- On failure, responds with
SdkError<ListTagsForResourceError>
Constructs a fluent builder for the ListWebsiteAuthorizationProviders operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
next_token(impl Into<String>)/set_next_token(Option<String>):The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
max_results(i32)/set_max_results(Option<i32>):The maximum number of results to be included in the next page.
- On success, responds with
ListWebsiteAuthorizationProvidersOutputwith field(s):website_authorization_providers(Option<Vec<WebsiteAuthorizationProviderSummary>>):The website authorization providers.
next_token(Option<String>):The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
- On failure, responds with
SdkError<ListWebsiteAuthorizationProvidersError>
Constructs a fluent builder for the ListWebsiteCertificateAuthorities operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
max_results(i32)/set_max_results(Option<i32>):The maximum number of results to be included in the next page.
next_token(impl Into<String>)/set_next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
- On success, responds with
ListWebsiteCertificateAuthoritiesOutputwith field(s):website_certificate_authorities(Option<Vec<WebsiteCaSummary>>):Information about the certificates.
next_token(Option<String>):The pagination token used to retrieve the next page of results for this operation. If there are no more pages, this value is null.
- On failure, responds with
SdkError<ListWebsiteCertificateAuthoritiesError>
Constructs a fluent builder for the RestoreDomainAccess operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
domain_name(impl Into<String>)/set_domain_name(Option<String>):The name of the domain.
- On success, responds with
RestoreDomainAccessOutput - On failure, responds with
SdkError<RestoreDomainAccessError>
Constructs a fluent builder for the RevokeDomainAccess operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
domain_name(impl Into<String>)/set_domain_name(Option<String>):The name of the domain.
- On success, responds with
RevokeDomainAccessOutput - On failure, responds with
SdkError<RevokeDomainAccessError>
Constructs a fluent builder for the SignOutUser operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
username(impl Into<String>)/set_username(Option<String>):The name of the user.
- On success, responds with
SignOutUserOutput - On failure, responds with
SdkError<SignOutUserError>
Constructs a fluent builder for the TagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The Amazon Resource Name (ARN) of the fleet.
tags(HashMap<String, String>)/set_tags(Option<HashMap<String, String>>):The tags to add to the resource. A tag is a key-value pair.
- On success, responds with
TagResourceOutput - On failure, responds with
SdkError<TagResourceError>
Constructs a fluent builder for the UntagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The Amazon Resource Name (ARN) of the fleet.
tag_keys(Vec<String>)/set_tag_keys(Option<Vec<String>>):The list of tag keys to remove from the resource.
- On success, responds with
UntagResourceOutput - On failure, responds with
SdkError<UntagResourceError>
Constructs a fluent builder for the UpdateAuditStreamConfiguration operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
audit_stream_arn(impl Into<String>)/set_audit_stream_arn(Option<String>):The ARN of the Amazon Kinesis data stream that receives the audit events.
- On success, responds with
UpdateAuditStreamConfigurationOutput - On failure, responds with
SdkError<UpdateAuditStreamConfigurationError>
pub fn update_company_network_configuration(
&self
) -> UpdateCompanyNetworkConfiguration<C, M, R>
pub fn update_company_network_configuration(
&self
) -> UpdateCompanyNetworkConfiguration<C, M, R>
Constructs a fluent builder for the UpdateCompanyNetworkConfiguration operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
vpc_id(impl Into<String>)/set_vpc_id(Option<String>):The VPC with connectivity to associated websites.
subnet_ids(Vec<String>)/set_subnet_ids(Option<Vec<String>>):The subnets used for X-ENI connections from Amazon WorkLink rendering containers.
security_group_ids(Vec<String>)/set_security_group_ids(Option<Vec<String>>):The security groups associated with access to the provided subnets.
- On success, responds with
UpdateCompanyNetworkConfigurationOutput - On failure, responds with
SdkError<UpdateCompanyNetworkConfigurationError>
Constructs a fluent builder for the UpdateDevicePolicyConfiguration operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
device_ca_certificate(impl Into<String>)/set_device_ca_certificate(Option<String>):The certificate chain, including intermediate certificates and the root certificate authority certificate used to issue device certificates.
- On success, responds with
UpdateDevicePolicyConfigurationOutput - On failure, responds with
SdkError<UpdateDevicePolicyConfigurationError>
Constructs a fluent builder for the UpdateDomainMetadata operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
domain_name(impl Into<String>)/set_domain_name(Option<String>):The name of the domain.
display_name(impl Into<String>)/set_display_name(Option<String>):The name to display.
- On success, responds with
UpdateDomainMetadataOutput - On failure, responds with
SdkError<UpdateDomainMetadataError>
Constructs a fluent builder for the UpdateFleetMetadata operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
display_name(impl Into<String>)/set_display_name(Option<String>):The fleet name to display. The existing DisplayName is unset if null is passed.
optimize_for_end_user_location(bool)/set_optimize_for_end_user_location(Option<bool>):The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
- On success, responds with
UpdateFleetMetadataOutput - On failure, responds with
SdkError<UpdateFleetMetadataError>
pub fn update_identity_provider_configuration(
&self
) -> UpdateIdentityProviderConfiguration<C, M, R>
pub fn update_identity_provider_configuration(
&self
) -> UpdateIdentityProviderConfiguration<C, M, R>
Constructs a fluent builder for the UpdateIdentityProviderConfiguration operation.
- The fluent builder is configurable:
fleet_arn(impl Into<String>)/set_fleet_arn(Option<String>):The ARN of the fleet.
identity_provider_type(IdentityProviderType)/set_identity_provider_type(Option<IdentityProviderType>):The type of identity provider.
identity_provider_saml_metadata(impl Into<String>)/set_identity_provider_saml_metadata(Option<String>):The SAML metadata document provided by the customer’s identity provider. The existing IdentityProviderSamlMetadata is unset if null is passed.
- On success, responds with
UpdateIdentityProviderConfigurationOutput - On failure, responds with
SdkError<UpdateIdentityProviderConfigurationError>
Creates a client with the given service config and connector override.