Module aws_sdk_worklink::error
source · Expand description
All error types that operations can return. Documentation on these types is copied from the model.
Modules
Structs
Error type for the
AssociateDomain operation.Error type for the
AssociateWebsiteAuthorizationProvider operation.Error type for the
AssociateWebsiteCertificateAuthority operation.Error type for the
CreateFleet operation.Error type for the
DeleteFleet operation.Error type for the
DescribeAuditStreamConfiguration operation.Error type for the
DescribeCompanyNetworkConfiguration operation.Error type for the
DescribeDevice operation.Error type for the
DescribeDevicePolicyConfiguration operation.Error type for the
DescribeDomain operation.Error type for the
DescribeFleetMetadata operation.Error type for the
DescribeIdentityProviderConfiguration operation.Error type for the
DescribeWebsiteCertificateAuthority operation.Error type for the
DisassociateDomain operation.Error type for the
DisassociateWebsiteAuthorizationProvider operation.Error type for the
DisassociateWebsiteCertificateAuthority operation.The service is temporarily unavailable.
The request is not valid.
Error type for the
ListDevices operation.Error type for the
ListDomains operation.Error type for the
ListFleets operation.Error type for the
ListTagsForResource operation.Error type for the
ListWebsiteAuthorizationProviders operation.Error type for the
ListWebsiteCertificateAuthorities operation.The resource already exists.
The requested resource was not found.
Error type for the
RestoreDomainAccess operation.Error type for the
RevokeDomainAccess operation.Error type for the
SignOutUser operation.Error type for the
TagResource operation.The number of requests exceeds the limit.
You are not authorized to perform this action.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Error type for the
UntagResource operation.Error type for the
UpdateAuditStreamConfiguration operation.Error type for the
UpdateCompanyNetworkConfiguration operation.Error type for the
UpdateDevicePolicyConfiguration operation.Error type for the
UpdateDomainMetadata operation.Error type for the
UpdateFleetMetadata operation.Error type for the
UpdateIdentityProviderConfiguration operation.Enums
Types of errors that can occur for the
AssociateDomain operation.Types of errors that can occur for the
AssociateWebsiteAuthorizationProvider operation.Types of errors that can occur for the
AssociateWebsiteCertificateAuthority operation.Types of errors that can occur for the
CreateFleet operation.Types of errors that can occur for the
DeleteFleet operation.Types of errors that can occur for the
DescribeAuditStreamConfiguration operation.Types of errors that can occur for the
DescribeCompanyNetworkConfiguration operation.Types of errors that can occur for the
DescribeDevice operation.Types of errors that can occur for the
DescribeDevicePolicyConfiguration operation.Types of errors that can occur for the
DescribeDomain operation.Types of errors that can occur for the
DescribeFleetMetadata operation.Types of errors that can occur for the
DescribeIdentityProviderConfiguration operation.Types of errors that can occur for the
DescribeWebsiteCertificateAuthority operation.Types of errors that can occur for the
DisassociateDomain operation.Types of errors that can occur for the
DisassociateWebsiteAuthorizationProvider operation.Types of errors that can occur for the
DisassociateWebsiteCertificateAuthority operation.Types of errors that can occur for the
ListDevices operation.Types of errors that can occur for the
ListDomains operation.Types of errors that can occur for the
ListFleets operation.Types of errors that can occur for the
ListTagsForResource operation.Types of errors that can occur for the
ListWebsiteAuthorizationProviders operation.Types of errors that can occur for the
ListWebsiteCertificateAuthorities operation.Types of errors that can occur for the
RestoreDomainAccess operation.Types of errors that can occur for the
RevokeDomainAccess operation.Types of errors that can occur for the
SignOutUser operation.Types of errors that can occur for the
TagResource operation.Types of errors that can occur for the
UntagResource operation.Types of errors that can occur for the
UpdateAuditStreamConfiguration operation.Types of errors that can occur for the
UpdateCompanyNetworkConfiguration operation.Types of errors that can occur for the
UpdateDevicePolicyConfiguration operation.Types of errors that can occur for the
UpdateDomainMetadata operation.Types of errors that can occur for the
UpdateFleetMetadata operation.Types of errors that can occur for the
UpdateIdentityProviderConfiguration operation.