#[non_exhaustive]
pub enum DescribeAuditStreamConfigurationErrorKind {
InternalServerErrorException(InternalServerErrorException),
InvalidRequestException(InvalidRequestException),
ResourceNotFoundException(ResourceNotFoundException),
TooManyRequestsException(TooManyRequestsException),
UnauthorizedException(UnauthorizedException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the DescribeAuditStreamConfiguration operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InternalServerErrorException(InternalServerErrorException)
Tuple Fields
The service is temporarily unavailable.
InvalidRequestException(InvalidRequestException)
Tuple Fields
The request is not valid.
ResourceNotFoundException(ResourceNotFoundException)
Tuple Fields
The requested resource was not found.
TooManyRequestsException(TooManyRequestsException)
Tuple Fields
The number of requests exceeds the limit.
UnauthorizedException(UnauthorizedException)
Tuple Fields
You are not authorized to perform this action.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code