Struct aws_sdk_worklink::input::create_fleet_input::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for CreateFleetInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn fleet_name(self, input: impl Into<String>) -> Self
pub fn fleet_name(self, input: impl Into<String>) -> Self
A unique name for the fleet.
sourcepub fn set_fleet_name(self, input: Option<String>) -> Self
pub fn set_fleet_name(self, input: Option<String>) -> Self
A unique name for the fleet.
sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
The fleet name to display.
sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
The fleet name to display.
sourcepub fn optimize_for_end_user_location(self, input: bool) -> Self
pub fn optimize_for_end_user_location(self, input: bool) -> Self
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
sourcepub fn set_optimize_for_end_user_location(self, input: Option<bool>) -> Self
pub fn set_optimize_for_end_user_location(self, input: Option<bool>) -> Self
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags to add to the resource. A tag is a key-value pair.
The tags to add to the resource. A tag is a key-value pair.
sourcepub fn build(self) -> Result<CreateFleetInput, BuildError>
pub fn build(self) -> Result<CreateFleetInput, BuildError>
Consumes the builder and constructs a CreateFleetInput.