Struct aws_sdk_worklink::input::list_fleets_input::Builder
source · [−]#[non_exhaustive]pub struct Builder { /* private fields */ }Expand description
A builder for ListFleetsInput
Implementations
The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
The maximum number of results to be included in the next page.
The maximum number of results to be included in the next page.
Consumes the builder and constructs a ListFleetsInput