Struct aws_sdk_worklink::input::AssociateDomainInput
source · #[non_exhaustive]pub struct AssociateDomainInput { /* private fields */ }Implementations
sourceimpl AssociateDomainInput
impl AssociateDomainInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<AssociateDomain, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<AssociateDomain, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<AssociateDomain>
Examples found in repository?
src/client.rs (line 574)
560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602
pub async fn customize(
self,
) -> std::result::Result<
crate::operation::customize::CustomizableOperation<
crate::operation::AssociateDomain,
aws_http::retry::AwsResponseRetryClassifier,
>,
aws_smithy_http::result::SdkError<crate::error::AssociateDomainError>,
> {
let handle = self.handle.clone();
let operation = self
.inner
.build()
.map_err(aws_smithy_http::result::SdkError::construction_failure)?
.make_operation(&handle.conf)
.await
.map_err(aws_smithy_http::result::SdkError::construction_failure)?;
Ok(crate::operation::customize::CustomizableOperation { handle, operation })
}
/// Sends the request and returns the response.
///
/// If an error occurs, an `SdkError` will be returned with additional details that
/// can be matched against.
///
/// By default, any retryable failures will be retried twice. Retry behavior
/// is configurable with the [RetryConfig](aws_smithy_types::retry::RetryConfig), which can be
/// set when configuring the client.
pub async fn send(
self,
) -> std::result::Result<
crate::output::AssociateDomainOutput,
aws_smithy_http::result::SdkError<crate::error::AssociateDomainError>,
> {
let op = self
.inner
.build()
.map_err(aws_smithy_http::result::SdkError::construction_failure)?
.make_operation(&self.handle.conf)
.await
.map_err(aws_smithy_http::result::SdkError::construction_failure)?;
self.handle.client.call(op).await
}sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture AssociateDomainInput.
sourceimpl AssociateDomainInput
impl AssociateDomainInput
sourcepub fn domain_name(&self) -> Option<&str>
pub fn domain_name(&self) -> Option<&str>
The fully qualified domain name (FQDN).
sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The name to display.
sourcepub fn acm_certificate_arn(&self) -> Option<&str>
pub fn acm_certificate_arn(&self) -> Option<&str>
The ARN of an issued ACM certificate that is valid for the domain being associated.