Struct aws_sdk_worklink::input::CreateFleetInput
source · #[non_exhaustive]pub struct CreateFleetInput { /* private fields */ }Implementations
sourceimpl CreateFleetInput
impl CreateFleetInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateFleet, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateFleet, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<CreateFleet>
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture CreateFleetInput.
sourceimpl CreateFleetInput
impl CreateFleetInput
sourcepub fn fleet_name(&self) -> Option<&str>
pub fn fleet_name(&self) -> Option<&str>
A unique name for the fleet.
sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The fleet name to display.
sourcepub fn optimize_for_end_user_location(&self) -> Option<bool>
pub fn optimize_for_end_user_location(&self) -> Option<bool>
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
The tags to add to the resource. A tag is a key-value pair.