Struct aws_sdk_worklink::input::ListFleetsInput
source · [−]#[non_exhaustive]pub struct ListFleetsInput {
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
max_results: Option<i32>The maximum number of results to be included in the next page.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListFleets, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListFleets, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListFleets>
Creates a new builder-style object to manufacture ListFleetsInput
The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
The maximum number of results to be included in the next page.