#[non_exhaustive]pub struct ListWebsiteAuthorizationProvidersInput {
pub fleet_arn: Option<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fleet_arn: Option<String>The ARN of the fleet.
next_token: Option<String>The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
max_results: Option<i32>The maximum number of results to be included in the next page.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListWebsiteAuthorizationProviders, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListWebsiteAuthorizationProviders, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListWebsiteAuthorizationProviders>
Creates a new builder-style object to manufacture ListWebsiteAuthorizationProvidersInput
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
The maximum number of results to be included in the next page.