#[non_exhaustive]pub struct ListWebsiteCertificateAuthoritiesInput {
pub fleet_arn: Option<String>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fleet_arn: Option<String>The ARN of the fleet.
max_results: Option<i32>The maximum number of results to be included in the next page.
next_token: Option<String>The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListWebsiteCertificateAuthorities, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListWebsiteCertificateAuthorities, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListWebsiteCertificateAuthorities>
Creates a new builder-style object to manufacture ListWebsiteCertificateAuthoritiesInput
The maximum number of results to be included in the next page.
The pagination token used to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.