#[non_exhaustive]pub struct UpdateCompanyNetworkConfigurationInput { /* private fields */ }Implementations
sourceimpl UpdateCompanyNetworkConfigurationInput
impl UpdateCompanyNetworkConfigurationInput
sourcepub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateCompanyNetworkConfiguration, AwsResponseRetryClassifier>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateCompanyNetworkConfiguration, AwsResponseRetryClassifier>, BuildError>
Consumes the builder and constructs an Operation<UpdateCompanyNetworkConfiguration>
Examples found in repository?
src/client.rs (line 3137)
3123 3124 3125 3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 3136 3137 3138 3139 3140 3141 3142 3143 3144 3145 3146 3147 3148 3149 3150 3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165
pub async fn customize(
self,
) -> std::result::Result<
crate::operation::customize::CustomizableOperation<
crate::operation::UpdateCompanyNetworkConfiguration,
aws_http::retry::AwsResponseRetryClassifier,
>,
aws_smithy_http::result::SdkError<crate::error::UpdateCompanyNetworkConfigurationError>,
> {
let handle = self.handle.clone();
let operation = self
.inner
.build()
.map_err(aws_smithy_http::result::SdkError::construction_failure)?
.make_operation(&handle.conf)
.await
.map_err(aws_smithy_http::result::SdkError::construction_failure)?;
Ok(crate::operation::customize::CustomizableOperation { handle, operation })
}
/// Sends the request and returns the response.
///
/// If an error occurs, an `SdkError` will be returned with additional details that
/// can be matched against.
///
/// By default, any retryable failures will be retried twice. Retry behavior
/// is configurable with the [RetryConfig](aws_smithy_types::retry::RetryConfig), which can be
/// set when configuring the client.
pub async fn send(
self,
) -> std::result::Result<
crate::output::UpdateCompanyNetworkConfigurationOutput,
aws_smithy_http::result::SdkError<crate::error::UpdateCompanyNetworkConfigurationError>,
> {
let op = self
.inner
.build()
.map_err(aws_smithy_http::result::SdkError::construction_failure)?
.make_operation(&self.handle.conf)
.await
.map_err(aws_smithy_http::result::SdkError::construction_failure)?;
self.handle.client.call(op).await
}sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture UpdateCompanyNetworkConfigurationInput.
sourceimpl UpdateCompanyNetworkConfigurationInput
impl UpdateCompanyNetworkConfigurationInput
sourcepub fn subnet_ids(&self) -> Option<&[String]>
pub fn subnet_ids(&self) -> Option<&[String]>
The subnets used for X-ENI connections from Amazon WorkLink rendering containers.
sourcepub fn security_group_ids(&self) -> Option<&[String]>
pub fn security_group_ids(&self) -> Option<&[String]>
The security groups associated with access to the provided subnets.