Struct aws_sdk_worklink::input::UpdateFleetMetadataInput [−][src]
#[non_exhaustive]pub struct UpdateFleetMetadataInput {
pub fleet_arn: Option<String>,
pub display_name: Option<String>,
pub optimize_for_end_user_location: Option<bool>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fleet_arn: Option<String>The ARN of the fleet.
display_name: Option<String>The fleet name to display. The existing DisplayName is unset if null is passed.
optimize_for_end_user_location: Option<bool>The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateFleetMetadata, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateFleetMetadata, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdateFleetMetadata>
Creates a new builder-style object to manufacture UpdateFleetMetadataInput
The fleet name to display. The existing DisplayName is unset if null is passed.
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.