Struct aws_sdk_worklink::input::update_fleet_metadata_input::Builder
source · [−]#[non_exhaustive]pub struct Builder { /* private fields */ }Expand description
A builder for UpdateFleetMetadataInput
Implementations
The ARN of the fleet.
The fleet name to display. The existing DisplayName is unset if null is passed.
The fleet name to display. The existing DisplayName is unset if null is passed.
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
Consumes the builder and constructs a UpdateFleetMetadataInput