#[non_exhaustive]pub enum AssociateDomainError {
InternalServerErrorException(InternalServerErrorException),
InvalidRequestException(InvalidRequestException),
ResourceAlreadyExistsException(ResourceAlreadyExistsException),
ResourceNotFoundException(ResourceNotFoundException),
TooManyRequestsException(TooManyRequestsException),
UnauthorizedException(UnauthorizedException),
Unhandled(Unhandled),
}Expand description
Error type for the AssociateDomainError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InternalServerErrorException(InternalServerErrorException)
The service is temporarily unavailable.
InvalidRequestException(InvalidRequestException)
The request is not valid.
ResourceAlreadyExistsException(ResourceAlreadyExistsException)
The resource already exists.
ResourceNotFoundException(ResourceNotFoundException)
The requested resource was not found.
TooManyRequestsException(TooManyRequestsException)
The number of requests exceeds the limit.
You are not authorized to perform this action.
Unhandled(Unhandled)
Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
sourceimpl AssociateDomainError
impl AssociateDomainError
sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the AssociateDomainError::Unhandled variant from any error type.
sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the AssociateDomainError::Unhandled variant from an ErrorMetadata.
sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
sourcepub fn is_internal_server_error_exception(&self) -> bool
pub fn is_internal_server_error_exception(&self) -> bool
Returns true if the error kind is AssociateDomainError::InternalServerErrorException.
sourcepub fn is_invalid_request_exception(&self) -> bool
pub fn is_invalid_request_exception(&self) -> bool
Returns true if the error kind is AssociateDomainError::InvalidRequestException.
sourcepub fn is_resource_already_exists_exception(&self) -> bool
pub fn is_resource_already_exists_exception(&self) -> bool
Returns true if the error kind is AssociateDomainError::ResourceAlreadyExistsException.
sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is AssociateDomainError::ResourceNotFoundException.
sourcepub fn is_too_many_requests_exception(&self) -> bool
pub fn is_too_many_requests_exception(&self) -> bool
Returns true if the error kind is AssociateDomainError::TooManyRequestsException.
Returns true if the error kind is AssociateDomainError::UnauthorizedException.