#[non_exhaustive]pub struct AssociateDomainInput {
pub fleet_arn: Option<String>,
pub domain_name: Option<String>,
pub display_name: Option<String>,
pub acm_certificate_arn: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fleet_arn: Option<String>The Amazon Resource Name (ARN) of the fleet.
domain_name: Option<String>The fully qualified domain name (FQDN).
display_name: Option<String>The name to display.
acm_certificate_arn: Option<String>The ARN of an issued ACM certificate that is valid for the domain being associated.
Implementations
sourceimpl AssociateDomainInput
impl AssociateDomainInput
sourcepub fn domain_name(&self) -> Option<&str>
pub fn domain_name(&self) -> Option<&str>
The fully qualified domain name (FQDN).
sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The name to display.
sourcepub fn acm_certificate_arn(&self) -> Option<&str>
pub fn acm_certificate_arn(&self) -> Option<&str>
The ARN of an issued ACM certificate that is valid for the domain being associated.
sourceimpl AssociateDomainInput
impl AssociateDomainInput
sourcepub fn builder() -> AssociateDomainInputBuilder
pub fn builder() -> AssociateDomainInputBuilder
Creates a new builder-style object to manufacture AssociateDomainInput.