#[non_exhaustive]pub struct CreateFleetInputBuilder { /* private fields */ }Expand description
A builder for CreateFleetInput.
Implementations
sourceimpl CreateFleetInputBuilder
impl CreateFleetInputBuilder
sourcepub fn fleet_name(self, input: impl Into<String>) -> Self
pub fn fleet_name(self, input: impl Into<String>) -> Self
A unique name for the fleet.
This field is required.sourcepub fn set_fleet_name(self, input: Option<String>) -> Self
pub fn set_fleet_name(self, input: Option<String>) -> Self
A unique name for the fleet.
sourcepub fn get_fleet_name(&self) -> &Option<String>
pub fn get_fleet_name(&self) -> &Option<String>
A unique name for the fleet.
sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
The fleet name to display.
sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
The fleet name to display.
sourcepub fn get_display_name(&self) -> &Option<String>
pub fn get_display_name(&self) -> &Option<String>
The fleet name to display.
sourcepub fn optimize_for_end_user_location(self, input: bool) -> Self
pub fn optimize_for_end_user_location(self, input: bool) -> Self
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
sourcepub fn set_optimize_for_end_user_location(self, input: Option<bool>) -> Self
pub fn set_optimize_for_end_user_location(self, input: Option<bool>) -> Self
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
sourcepub fn get_optimize_for_end_user_location(&self) -> &Option<bool>
pub fn get_optimize_for_end_user_location(&self) -> &Option<bool>
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags to add to the resource. A tag is a key-value pair.
The tags to add to the resource. A tag is a key-value pair.
The tags to add to the resource. A tag is a key-value pair.
sourcepub fn build(self) -> Result<CreateFleetInput, BuildError>
pub fn build(self) -> Result<CreateFleetInput, BuildError>
Consumes the builder and constructs a CreateFleetInput.
sourceimpl CreateFleetInputBuilder
impl CreateFleetInputBuilder
sourcepub async fn send_with(
self,
client: &Client
) -> Result<CreateFleetOutput, SdkError<CreateFleetError, HttpResponse>>
pub async fn send_with( self, client: &Client ) -> Result<CreateFleetOutput, SdkError<CreateFleetError, HttpResponse>>
Sends a request with this input using the given client.