Struct aws_sdk_worklink::operation::create_fleet::CreateFleetInput
source · #[non_exhaustive]pub struct CreateFleetInput {
pub fleet_name: Option<String>,
pub display_name: Option<String>,
pub optimize_for_end_user_location: Option<bool>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fleet_name: Option<String>A unique name for the fleet.
display_name: Option<String>The fleet name to display.
optimize_for_end_user_location: Option<bool>The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
The tags to add to the resource. A tag is a key-value pair.
Implementations
sourceimpl CreateFleetInput
impl CreateFleetInput
sourcepub fn fleet_name(&self) -> Option<&str>
pub fn fleet_name(&self) -> Option<&str>
A unique name for the fleet.
sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The fleet name to display.
sourcepub fn optimize_for_end_user_location(&self) -> Option<bool>
pub fn optimize_for_end_user_location(&self) -> Option<bool>
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
The tags to add to the resource. A tag is a key-value pair.
sourceimpl CreateFleetInput
impl CreateFleetInput
sourcepub fn builder() -> CreateFleetInputBuilder
pub fn builder() -> CreateFleetInputBuilder
Creates a new builder-style object to manufacture CreateFleetInput.