#[non_exhaustive]pub enum DisassociateDomainError {
InternalServerErrorException(InternalServerErrorException),
InvalidRequestException(InvalidRequestException),
ResourceNotFoundException(ResourceNotFoundException),
TooManyRequestsException(TooManyRequestsException),
UnauthorizedException(UnauthorizedException),
Unhandled(Unhandled),
}Expand description
Error type for the DisassociateDomainError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InternalServerErrorException(InternalServerErrorException)
The service is temporarily unavailable.
InvalidRequestException(InvalidRequestException)
The request is not valid.
ResourceNotFoundException(ResourceNotFoundException)
The requested resource was not found.
TooManyRequestsException(TooManyRequestsException)
The number of requests exceeds the limit.
You are not authorized to perform this action.
Unhandled(Unhandled)
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
sourceimpl DisassociateDomainError
impl DisassociateDomainError
sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the DisassociateDomainError::Unhandled variant from any error type.
sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the DisassociateDomainError::Unhandled variant from a ::aws_smithy_types::error::ErrorMetadata.
sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
sourcepub fn is_internal_server_error_exception(&self) -> bool
pub fn is_internal_server_error_exception(&self) -> bool
Returns true if the error kind is DisassociateDomainError::InternalServerErrorException.
sourcepub fn is_invalid_request_exception(&self) -> bool
pub fn is_invalid_request_exception(&self) -> bool
Returns true if the error kind is DisassociateDomainError::InvalidRequestException.
sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is DisassociateDomainError::ResourceNotFoundException.
sourcepub fn is_too_many_requests_exception(&self) -> bool
pub fn is_too_many_requests_exception(&self) -> bool
Returns true if the error kind is DisassociateDomainError::TooManyRequestsException.
Returns true if the error kind is DisassociateDomainError::UnauthorizedException.