#[non_exhaustive]pub enum ListFleetsError {
InternalServerErrorException(InternalServerErrorException),
InvalidRequestException(InvalidRequestException),
TooManyRequestsException(TooManyRequestsException),
UnauthorizedException(UnauthorizedException),
Unhandled(Unhandled),
}Expand description
Error type for the ListFleetsError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InternalServerErrorException(InternalServerErrorException)
The service is temporarily unavailable.
InvalidRequestException(InvalidRequestException)
The request is not valid.
TooManyRequestsException(TooManyRequestsException)
The number of requests exceeds the limit.
You are not authorized to perform this action.
Unhandled(Unhandled)
Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
sourceimpl ListFleetsError
impl ListFleetsError
sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the ListFleetsError::Unhandled variant from any error type.
sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the ListFleetsError::Unhandled variant from an ErrorMetadata.
sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
sourcepub fn is_internal_server_error_exception(&self) -> bool
pub fn is_internal_server_error_exception(&self) -> bool
Returns true if the error kind is ListFleetsError::InternalServerErrorException.
sourcepub fn is_invalid_request_exception(&self) -> bool
pub fn is_invalid_request_exception(&self) -> bool
Returns true if the error kind is ListFleetsError::InvalidRequestException.
sourcepub fn is_too_many_requests_exception(&self) -> bool
pub fn is_too_many_requests_exception(&self) -> bool
Returns true if the error kind is ListFleetsError::TooManyRequestsException.
Returns true if the error kind is ListFleetsError::UnauthorizedException.