Struct aws_sdk_worklink::operation::list_fleets::ListFleetsOutput
source · #[non_exhaustive]pub struct ListFleetsOutput {
pub fleet_summary_list: Option<Vec<FleetSummary>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fleet_summary_list: Option<Vec<FleetSummary>>The summary list of the fleets.
next_token: Option<String>The pagination token used to retrieve the next page of results for this operation. If there are no more pages, this value is null.
Implementations
sourceimpl ListFleetsOutput
impl ListFleetsOutput
sourcepub fn fleet_summary_list(&self) -> &[FleetSummary]
pub fn fleet_summary_list(&self) -> &[FleetSummary]
The summary list of the fleets.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .fleet_summary_list.is_none().
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The pagination token used to retrieve the next page of results for this operation. If there are no more pages, this value is null.
sourceimpl ListFleetsOutput
impl ListFleetsOutput
sourcepub fn builder() -> ListFleetsOutputBuilder
pub fn builder() -> ListFleetsOutputBuilder
Creates a new builder-style object to manufacture ListFleetsOutput.