#[non_exhaustive]pub struct UpdateFleetMetadataInput {
pub fleet_arn: Option<String>,
pub display_name: Option<String>,
pub optimize_for_end_user_location: Option<bool>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fleet_arn: Option<String>The ARN of the fleet.
display_name: Option<String>The fleet name to display. The existing DisplayName is unset if null is passed.
optimize_for_end_user_location: Option<bool>The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
Implementations
Sourceimpl UpdateFleetMetadataInput
impl UpdateFleetMetadataInput
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The fleet name to display. The existing DisplayName is unset if null is passed.
Sourcepub fn optimize_for_end_user_location(&self) -> Option<bool>
pub fn optimize_for_end_user_location(&self) -> Option<bool>
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
Sourceimpl UpdateFleetMetadataInput
impl UpdateFleetMetadataInput
Sourcepub fn builder() -> UpdateFleetMetadataInputBuilder
pub fn builder() -> UpdateFleetMetadataInputBuilder
Creates a new builder-style object to manufacture UpdateFleetMetadataInput.