#[non_exhaustive]pub struct DescribeCompanyNetworkConfigurationOutput {
pub vpc_id: Option<String>,
pub subnet_ids: Option<Vec<String>>,
pub security_group_ids: Option<Vec<String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.vpc_id: Option<String>The VPC with connectivity to associated websites.
subnet_ids: Option<Vec<String>>The subnets used for X-ENI connections from Amazon WorkLink rendering containers.
security_group_ids: Option<Vec<String>>The security groups associated with access to the provided subnets.
Implementations
sourceimpl DescribeCompanyNetworkConfigurationOutput
impl DescribeCompanyNetworkConfigurationOutput
sourcepub fn subnet_ids(&self) -> Option<&[String]>
pub fn subnet_ids(&self) -> Option<&[String]>
The subnets used for X-ENI connections from Amazon WorkLink rendering containers.
sourcepub fn security_group_ids(&self) -> Option<&[String]>
pub fn security_group_ids(&self) -> Option<&[String]>
The security groups associated with access to the provided subnets.
sourceimpl DescribeCompanyNetworkConfigurationOutput
impl DescribeCompanyNetworkConfigurationOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeCompanyNetworkConfigurationOutput