#[non_exhaustive]
pub struct DescribeDeviceOutput { /* private fields */ }

Implementations

The current state of the device.

The model of the device.

The manufacturer of the device.

The operating system of the device.

The operating system version of the device.

The operating system patch level of the device.

The date that the device first signed in to Amazon WorkLink.

The date that the device last accessed Amazon WorkLink.

The user name associated with the device.

Creates a new builder-style object to manufacture DescribeDeviceOutput.