Struct aws_sdk_worklink::output::ListDevicesOutput
source · #[non_exhaustive]pub struct ListDevicesOutput { /* private fields */ }Implementations
sourceimpl ListDevicesOutput
impl ListDevicesOutput
sourcepub fn devices(&self) -> Option<&[DeviceSummary]>
pub fn devices(&self) -> Option<&[DeviceSummary]>
Information about the devices.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The pagination token used to retrieve the next page of results for this operation. If there are no more pages, this value is null.
sourceimpl ListDevicesOutput
impl ListDevicesOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture ListDevicesOutput.