Struct aws_sdk_worklink::output::ListDomainsOutput
source · #[non_exhaustive]pub struct ListDomainsOutput { /* private fields */ }Implementations
sourceimpl ListDomainsOutput
impl ListDomainsOutput
sourcepub fn domains(&self) -> Option<&[DomainSummary]>
pub fn domains(&self) -> Option<&[DomainSummary]>
Information about the domains.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The pagination token used to retrieve the next page of results for this operation. If there are no more pages, this value is null.
sourceimpl ListDomainsOutput
impl ListDomainsOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture ListDomainsOutput.