Struct aws_sdk_worklink::output::ListWebsiteAuthorizationProvidersOutput [−][src]
#[non_exhaustive]pub struct ListWebsiteAuthorizationProvidersOutput {
pub website_authorization_providers: Option<Vec<WebsiteAuthorizationProviderSummary>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.The website authorization providers.
next_token: Option<String>The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
Implementations
The website authorization providers.
The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.
Creates a new builder-style object to manufacture ListWebsiteAuthorizationProvidersOutput