Struct aws_sdk_worklink::client::fluent_builders::AssociateDomain
source · [−]pub struct AssociateDomain<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to AssociateDomain.
Specifies a domain to be associated to Amazon WorkLink.
Implementations
impl<C, M, R> AssociateDomain<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> AssociateDomain<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<AssociateDomainOutput, SdkError<AssociateDomainError>> where
R::Policy: SmithyRetryPolicy<AssociateDomainInputOperationOutputAlias, AssociateDomainOutput, AssociateDomainError, AssociateDomainInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<AssociateDomainOutput, SdkError<AssociateDomainError>> where
R::Policy: SmithyRetryPolicy<AssociateDomainInputOperationOutputAlias, AssociateDomainOutput, AssociateDomainError, AssociateDomainInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The Amazon Resource Name (ARN) of the fleet.
The Amazon Resource Name (ARN) of the fleet.
The fully qualified domain name (FQDN).
The fully qualified domain name (FQDN).
The name to display.
The name to display.
The ARN of an issued ACM certificate that is valid for the domain being associated.
The ARN of an issued ACM certificate that is valid for the domain being associated.