pub struct AssociateWebsiteAuthorizationProvider<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to AssociateWebsiteAuthorizationProvider.
Associates a website authorization provider with a specified fleet. This is used to authorize users against associated websites in the company network.
Implementations
impl<C, M, R> AssociateWebsiteAuthorizationProvider<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> AssociateWebsiteAuthorizationProvider<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<AssociateWebsiteAuthorizationProviderOutput, SdkError<AssociateWebsiteAuthorizationProviderError>> where
R::Policy: SmithyRetryPolicy<AssociateWebsiteAuthorizationProviderInputOperationOutputAlias, AssociateWebsiteAuthorizationProviderOutput, AssociateWebsiteAuthorizationProviderError, AssociateWebsiteAuthorizationProviderInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<AssociateWebsiteAuthorizationProviderOutput, SdkError<AssociateWebsiteAuthorizationProviderError>> where
R::Policy: SmithyRetryPolicy<AssociateWebsiteAuthorizationProviderInputOperationOutputAlias, AssociateWebsiteAuthorizationProviderOutput, AssociateWebsiteAuthorizationProviderError, AssociateWebsiteAuthorizationProviderInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ARN of the fleet.
The authorization provider type.
The authorization provider type.
The domain name of the authorization provider. This applies only to SAML-based authorization providers.
The domain name of the authorization provider. This applies only to SAML-based authorization providers.