Struct aws_sdk_worklink::client::fluent_builders::CreateFleet
source · [−]pub struct CreateFleet<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to CreateFleet.
Creates a fleet. A fleet consists of resources and the configuration that delivers associated websites to authorized users who download and set up the Amazon WorkLink app.
Implementations
impl<C, M, R> CreateFleet<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> CreateFleet<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(self) -> Result<CreateFleetOutput, SdkError<CreateFleetError>> where
R::Policy: SmithyRetryPolicy<CreateFleetInputOperationOutputAlias, CreateFleetOutput, CreateFleetError, CreateFleetInputOperationRetryAlias>,
pub async fn send(self) -> Result<CreateFleetOutput, SdkError<CreateFleetError>> where
R::Policy: SmithyRetryPolicy<CreateFleetInputOperationOutputAlias, CreateFleetOutput, CreateFleetError, CreateFleetInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
A unique name for the fleet.
A unique name for the fleet.
The fleet name to display.
The fleet name to display.
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
Adds a key-value pair to Tags.
To override the contents of this collection use set_tags.
The tags to add to the resource. A tag is a key-value pair.
The tags to add to the resource. A tag is a key-value pair.