Struct aws_sdk_worklink::client::fluent_builders::DescribeDevice
source · [−]pub struct DescribeDevice<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to DescribeDevice.
Provides information about a user's device.
Implementations
impl<C, M, R> DescribeDevice<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> DescribeDevice<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<DescribeDeviceOutput, SdkError<DescribeDeviceError>> where
R::Policy: SmithyRetryPolicy<DescribeDeviceInputOperationOutputAlias, DescribeDeviceOutput, DescribeDeviceError, DescribeDeviceInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<DescribeDeviceOutput, SdkError<DescribeDeviceError>> where
R::Policy: SmithyRetryPolicy<DescribeDeviceInputOperationOutputAlias, DescribeDeviceOutput, DescribeDeviceError, DescribeDeviceInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ARN of the fleet.
A unique identifier for a registered user's device.
A unique identifier for a registered user's device.