pub struct DescribeDevicePolicyConfiguration { /* private fields */ }Expand description
Fluent builder constructing a request to DescribeDevicePolicyConfiguration.
Describes the device policy configuration for the specified fleet.
Implementations
sourceimpl DescribeDevicePolicyConfiguration
impl DescribeDevicePolicyConfiguration
sourcepub async fn send(
self
) -> Result<DescribeDevicePolicyConfigurationOutput, SdkError<DescribeDevicePolicyConfigurationError>>
pub async fn send(
self
) -> Result<DescribeDevicePolicyConfigurationOutput, SdkError<DescribeDevicePolicyConfigurationError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The ARN of the fleet.