Struct aws_sdk_worklink::client::fluent_builders::DisassociateDomain [−][src]
pub struct DisassociateDomain<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to DisassociateDomain.
Disassociates a domain from Amazon WorkLink. End users lose the ability to access the domain with Amazon WorkLink.
Implementations
impl<C, M, R> DisassociateDomain<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> DisassociateDomain<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<DisassociateDomainOutput, SdkError<DisassociateDomainError>> where
R::Policy: SmithyRetryPolicy<DisassociateDomainInputOperationOutputAlias, DisassociateDomainOutput, DisassociateDomainError, DisassociateDomainInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<DisassociateDomainOutput, SdkError<DisassociateDomainError>> where
R::Policy: SmithyRetryPolicy<DisassociateDomainInputOperationOutputAlias, DisassociateDomainOutput, DisassociateDomainError, DisassociateDomainInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ARN of the fleet.
The name of the domain.
The name of the domain.