Struct aws_sdk_worklink::client::fluent_builders::DisassociateWebsiteAuthorizationProvider
source · [−]pub struct DisassociateWebsiteAuthorizationProvider<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to DisassociateWebsiteAuthorizationProvider.
Disassociates a website authorization provider from a specified fleet. After the disassociation, users can't load any associated websites that require this authorization provider.
Implementations
impl<C, M, R> DisassociateWebsiteAuthorizationProvider<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> DisassociateWebsiteAuthorizationProvider<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<DisassociateWebsiteAuthorizationProviderOutput, SdkError<DisassociateWebsiteAuthorizationProviderError>> where
R::Policy: SmithyRetryPolicy<DisassociateWebsiteAuthorizationProviderInputOperationOutputAlias, DisassociateWebsiteAuthorizationProviderOutput, DisassociateWebsiteAuthorizationProviderError, DisassociateWebsiteAuthorizationProviderInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<DisassociateWebsiteAuthorizationProviderOutput, SdkError<DisassociateWebsiteAuthorizationProviderError>> where
R::Policy: SmithyRetryPolicy<DisassociateWebsiteAuthorizationProviderInputOperationOutputAlias, DisassociateWebsiteAuthorizationProviderOutput, DisassociateWebsiteAuthorizationProviderError, DisassociateWebsiteAuthorizationProviderInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ARN of the fleet.
A unique identifier for the authorization provider.
A unique identifier for the authorization provider.