pub struct UpdateAuditStreamConfiguration<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateAuditStreamConfiguration.
Updates the audit stream configuration for the fleet.
Implementations
impl<C, M, R> UpdateAuditStreamConfiguration<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> UpdateAuditStreamConfiguration<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<UpdateAuditStreamConfigurationOutput, SdkError<UpdateAuditStreamConfigurationError>> where
R::Policy: SmithyRetryPolicy<UpdateAuditStreamConfigurationInputOperationOutputAlias, UpdateAuditStreamConfigurationOutput, UpdateAuditStreamConfigurationError, UpdateAuditStreamConfigurationInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<UpdateAuditStreamConfigurationOutput, SdkError<UpdateAuditStreamConfigurationError>> where
R::Policy: SmithyRetryPolicy<UpdateAuditStreamConfigurationInputOperationOutputAlias, UpdateAuditStreamConfigurationOutput, UpdateAuditStreamConfigurationError, UpdateAuditStreamConfigurationInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ARN of the fleet.
The ARN of the Amazon Kinesis data stream that receives the audit events.
The ARN of the Amazon Kinesis data stream that receives the audit events.