pub struct UpdateCompanyNetworkConfiguration<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateCompanyNetworkConfiguration.
Updates the company network configuration for the fleet.
Implementations
impl<C, M, R> UpdateCompanyNetworkConfiguration<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> UpdateCompanyNetworkConfiguration<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<UpdateCompanyNetworkConfigurationOutput, SdkError<UpdateCompanyNetworkConfigurationError>> where
R::Policy: SmithyRetryPolicy<UpdateCompanyNetworkConfigurationInputOperationOutputAlias, UpdateCompanyNetworkConfigurationOutput, UpdateCompanyNetworkConfigurationError, UpdateCompanyNetworkConfigurationInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<UpdateCompanyNetworkConfigurationOutput, SdkError<UpdateCompanyNetworkConfigurationError>> where
R::Policy: SmithyRetryPolicy<UpdateCompanyNetworkConfigurationInputOperationOutputAlias, UpdateCompanyNetworkConfigurationOutput, UpdateCompanyNetworkConfigurationError, UpdateCompanyNetworkConfigurationInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ARN of the fleet.
The VPC with connectivity to associated websites.
The VPC with connectivity to associated websites.
Appends an item to SubnetIds.
To override the contents of this collection use set_subnet_ids.
The subnets used for X-ENI connections from Amazon WorkLink rendering containers.
The subnets used for X-ENI connections from Amazon WorkLink rendering containers.
Appends an item to SecurityGroupIds.
To override the contents of this collection use set_security_group_ids.
The security groups associated with access to the provided subnets.
The security groups associated with access to the provided subnets.