pub struct UpdateDevicePolicyConfiguration<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* private fields */ }Expand description
Fluent builder constructing a request to UpdateDevicePolicyConfiguration.
Updates the device policy configuration for the fleet.
Implementations
impl<C, M, R> UpdateDevicePolicyConfiguration<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> UpdateDevicePolicyConfiguration<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<UpdateDevicePolicyConfigurationOutput, SdkError<UpdateDevicePolicyConfigurationError>> where
R::Policy: SmithyRetryPolicy<UpdateDevicePolicyConfigurationInputOperationOutputAlias, UpdateDevicePolicyConfigurationOutput, UpdateDevicePolicyConfigurationError, UpdateDevicePolicyConfigurationInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<UpdateDevicePolicyConfigurationOutput, SdkError<UpdateDevicePolicyConfigurationError>> where
R::Policy: SmithyRetryPolicy<UpdateDevicePolicyConfigurationInputOperationOutputAlias, UpdateDevicePolicyConfigurationOutput, UpdateDevicePolicyConfigurationError, UpdateDevicePolicyConfigurationInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ARN of the fleet.
The certificate chain, including intermediate certificates and the root certificate authority certificate used to issue device certificates.
The certificate chain, including intermediate certificates and the root certificate authority certificate used to issue device certificates.