pub struct UpdateIdentityProviderConfiguration<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to UpdateIdentityProviderConfiguration.
Updates the identity provider configuration for the fleet.
Implementations
impl<C, M, R> UpdateIdentityProviderConfiguration<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> UpdateIdentityProviderConfiguration<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<UpdateIdentityProviderConfigurationOutput, SdkError<UpdateIdentityProviderConfigurationError>> where
R::Policy: SmithyRetryPolicy<UpdateIdentityProviderConfigurationInputOperationOutputAlias, UpdateIdentityProviderConfigurationOutput, UpdateIdentityProviderConfigurationError, UpdateIdentityProviderConfigurationInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<UpdateIdentityProviderConfigurationOutput, SdkError<UpdateIdentityProviderConfigurationError>> where
R::Policy: SmithyRetryPolicy<UpdateIdentityProviderConfigurationInputOperationOutputAlias, UpdateIdentityProviderConfigurationOutput, UpdateIdentityProviderConfigurationError, UpdateIdentityProviderConfigurationInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ARN of the fleet.
The type of identity provider.
The type of identity provider.
The SAML metadata document provided by the customer’s identity provider. The existing IdentityProviderSamlMetadata is unset if null is passed.
The SAML metadata document provided by the customer’s identity provider. The existing IdentityProviderSamlMetadata is unset if null is passed.