Struct aws_sdk_worklink::client::fluent_builders::UpdateIdentityProviderConfiguration[][src]

pub struct UpdateIdentityProviderConfiguration<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to UpdateIdentityProviderConfiguration.

Updates the identity provider configuration for the fleet.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The ARN of the fleet.

The ARN of the fleet.

The type of identity provider.

The type of identity provider.

The SAML metadata document provided by the customer’s identity provider. The existing IdentityProviderSamlMetadata is unset if null is passed.

The SAML metadata document provided by the customer’s identity provider. The existing IdentityProviderSamlMetadata is unset if null is passed.