Struct aws_sdk_worklink::client::Client
source ·
[−]pub struct Client<C = DynConnector, M = DefaultMiddleware, R = Standard> { /* fields omitted */ }Expand description
Client for Amazon WorkLink
Client for invoking operations on Amazon WorkLink. Each operation on Amazon WorkLink is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Examples
Constructing a client and invoking an operation
// create a shared configuration. This can be used & shared between multiple service clients.
let shared_config = aws_config::load_from_env().await;
let client = aws_sdk_worklink::Client::new(&shared_config);
// invoke an operation
/* let rsp = client
.<operation_name>().
.<param>("some value")
.send().await; */Constructing a client with custom configuration
use aws_config::RetryConfig;
let shared_config = aws_config::load_from_env().await;
let config = aws_sdk_worklink::config::Builder::from(&shared_config)
.retry_config(RetryConfig::disabled())
.build();
let client = aws_sdk_worklink::Client::from_conf(config);Implementations
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> Client<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
Constructs a fluent builder for the AssociateDomain operation.
See AssociateDomain for more information about the
operation and its arguments.
Constructs a fluent builder for the AssociateWebsiteAuthorizationProvider operation.
See AssociateWebsiteAuthorizationProvider for more information about the
operation and its arguments.
Constructs a fluent builder for the AssociateWebsiteCertificateAuthority operation.
See AssociateWebsiteCertificateAuthority for more information about the
operation and its arguments.
Constructs a fluent builder for the CreateFleet operation.
See CreateFleet for more information about the
operation and its arguments.
Constructs a fluent builder for the DeleteFleet operation.
See DeleteFleet for more information about the
operation and its arguments.
pub fn describe_audit_stream_configuration(
&self
) -> DescribeAuditStreamConfiguration<C, M, R>
pub fn describe_audit_stream_configuration(
&self
) -> DescribeAuditStreamConfiguration<C, M, R>
Constructs a fluent builder for the DescribeAuditStreamConfiguration operation.
See DescribeAuditStreamConfiguration for more information about the
operation and its arguments.
pub fn describe_company_network_configuration(
&self
) -> DescribeCompanyNetworkConfiguration<C, M, R>
pub fn describe_company_network_configuration(
&self
) -> DescribeCompanyNetworkConfiguration<C, M, R>
Constructs a fluent builder for the DescribeCompanyNetworkConfiguration operation.
See DescribeCompanyNetworkConfiguration for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeDevice operation.
See DescribeDevice for more information about the
operation and its arguments.
pub fn describe_device_policy_configuration(
&self
) -> DescribeDevicePolicyConfiguration<C, M, R>
pub fn describe_device_policy_configuration(
&self
) -> DescribeDevicePolicyConfiguration<C, M, R>
Constructs a fluent builder for the DescribeDevicePolicyConfiguration operation.
See DescribeDevicePolicyConfiguration for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeDomain operation.
See DescribeDomain for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeFleetMetadata operation.
See DescribeFleetMetadata for more information about the
operation and its arguments.
pub fn describe_identity_provider_configuration(
&self
) -> DescribeIdentityProviderConfiguration<C, M, R>
pub fn describe_identity_provider_configuration(
&self
) -> DescribeIdentityProviderConfiguration<C, M, R>
Constructs a fluent builder for the DescribeIdentityProviderConfiguration operation.
See DescribeIdentityProviderConfiguration for more information about the
operation and its arguments.
Constructs a fluent builder for the DescribeWebsiteCertificateAuthority operation.
See DescribeWebsiteCertificateAuthority for more information about the
operation and its arguments.
Constructs a fluent builder for the DisassociateDomain operation.
See DisassociateDomain for more information about the
operation and its arguments.
Constructs a fluent builder for the DisassociateWebsiteAuthorizationProvider operation.
See DisassociateWebsiteAuthorizationProvider for more information about the
operation and its arguments.
Constructs a fluent builder for the DisassociateWebsiteCertificateAuthority operation.
See DisassociateWebsiteCertificateAuthority for more information about the
operation and its arguments.
Constructs a fluent builder for the ListDevices operation.
See ListDevices for more information about the
operation and its arguments.
This operation supports pagination. See into_paginator().
Constructs a fluent builder for the ListDomains operation.
See ListDomains for more information about the
operation and its arguments.
This operation supports pagination. See into_paginator().
Constructs a fluent builder for the ListFleets operation.
See ListFleets for more information about the
operation and its arguments.
This operation supports pagination. See into_paginator().
Constructs a fluent builder for the ListTagsForResource operation.
See ListTagsForResource for more information about the
operation and its arguments.
Constructs a fluent builder for the ListWebsiteAuthorizationProviders operation.
See ListWebsiteAuthorizationProviders for more information about the
operation and its arguments.
This operation supports pagination. See into_paginator().
Constructs a fluent builder for the ListWebsiteCertificateAuthorities operation.
See ListWebsiteCertificateAuthorities for more information about the
operation and its arguments.
This operation supports pagination. See into_paginator().
Constructs a fluent builder for the RestoreDomainAccess operation.
See RestoreDomainAccess for more information about the
operation and its arguments.
Constructs a fluent builder for the RevokeDomainAccess operation.
See RevokeDomainAccess for more information about the
operation and its arguments.
Constructs a fluent builder for the SignOutUser operation.
See SignOutUser for more information about the
operation and its arguments.
Constructs a fluent builder for the TagResource operation.
See TagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UntagResource operation.
See UntagResource for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateAuditStreamConfiguration operation.
See UpdateAuditStreamConfiguration for more information about the
operation and its arguments.
pub fn update_company_network_configuration(
&self
) -> UpdateCompanyNetworkConfiguration<C, M, R>
pub fn update_company_network_configuration(
&self
) -> UpdateCompanyNetworkConfiguration<C, M, R>
Constructs a fluent builder for the UpdateCompanyNetworkConfiguration operation.
See UpdateCompanyNetworkConfiguration for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateDevicePolicyConfiguration operation.
See UpdateDevicePolicyConfiguration for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateDomainMetadata operation.
See UpdateDomainMetadata for more information about the
operation and its arguments.
Constructs a fluent builder for the UpdateFleetMetadata operation.
See UpdateFleetMetadata for more information about the
operation and its arguments.
pub fn update_identity_provider_configuration(
&self
) -> UpdateIdentityProviderConfiguration<C, M, R>
pub fn update_identity_provider_configuration(
&self
) -> UpdateIdentityProviderConfiguration<C, M, R>
Constructs a fluent builder for the UpdateIdentityProviderConfiguration operation.
See UpdateIdentityProviderConfiguration for more information about the
operation and its arguments.
Creates a client with the given service config and connector override.