pub struct Builder { /* private fields */ }
A builder for AssociateDomainInput.

Implementations

The Amazon Resource Name (ARN) of the fleet.

Examples found in repository?
src/client.rs (line 605)
604
605
606
607
        pub fn fleet_arn(mut self, input: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.fleet_arn(input.into());
            self
        }

The Amazon Resource Name (ARN) of the fleet.

Examples found in repository?
src/client.rs (line 610)
609
610
611
612
        pub fn set_fleet_arn(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_fleet_arn(input);
            self
        }

The fully qualified domain name (FQDN).

Examples found in repository?
src/client.rs (line 615)
614
615
616
617
        pub fn domain_name(mut self, input: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.domain_name(input.into());
            self
        }

The fully qualified domain name (FQDN).

Examples found in repository?
src/client.rs (line 620)
619
620
621
622
        pub fn set_domain_name(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_domain_name(input);
            self
        }

The name to display.

Examples found in repository?
src/client.rs (line 625)
624
625
626
627
        pub fn display_name(mut self, input: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.display_name(input.into());
            self
        }

The name to display.

Examples found in repository?
src/client.rs (line 630)
629
630
631
632
        pub fn set_display_name(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_display_name(input);
            self
        }

The ARN of an issued ACM certificate that is valid for the domain being associated.

Examples found in repository?
src/client.rs (line 635)
634
635
636
637
        pub fn acm_certificate_arn(mut self, input: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.acm_certificate_arn(input.into());
            self
        }

The ARN of an issued ACM certificate that is valid for the domain being associated.

Examples found in repository?
src/client.rs (line 643)
639
640
641
642
643
644
645
        pub fn set_acm_certificate_arn(
            mut self,
            input: std::option::Option<std::string::String>,
        ) -> Self {
            self.inner = self.inner.set_acm_certificate_arn(input);
            self
        }

Consumes the builder and constructs a AssociateDomainInput.

Examples found in repository?
src/client.rs (line 572)
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
        pub async fn customize(
            self,
        ) -> std::result::Result<
            crate::operation::customize::CustomizableOperation<
                crate::operation::AssociateDomain,
                aws_http::retry::AwsResponseRetryClassifier,
            >,
            aws_smithy_http::result::SdkError<crate::error::AssociateDomainError>,
        > {
            let handle = self.handle.clone();
            let operation = self
                .inner
                .build()
                .map_err(aws_smithy_http::result::SdkError::construction_failure)?
                .make_operation(&handle.conf)
                .await
                .map_err(aws_smithy_http::result::SdkError::construction_failure)?;
            Ok(crate::operation::customize::CustomizableOperation { handle, operation })
        }

        /// Sends the request and returns the response.
        ///
        /// If an error occurs, an `SdkError` will be returned with additional details that
        /// can be matched against.
        ///
        /// By default, any retryable failures will be retried twice. Retry behavior
        /// is configurable with the [RetryConfig](aws_smithy_types::retry::RetryConfig), which can be
        /// set when configuring the client.
        pub async fn send(
            self,
        ) -> std::result::Result<
            crate::output::AssociateDomainOutput,
            aws_smithy_http::result::SdkError<crate::error::AssociateDomainError>,
        > {
            let op = self
                .inner
                .build()
                .map_err(aws_smithy_http::result::SdkError::construction_failure)?
                .make_operation(&self.handle.conf)
                .await
                .map_err(aws_smithy_http::result::SdkError::construction_failure)?;
            self.handle.client.call(op).await
        }