Struct aws_sdk_worklink::input::associate_domain_input::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for AssociateDomainInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn fleet_arn(self, input: impl Into<String>) -> Self
pub fn fleet_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the fleet.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the fleet.
sourcepub fn domain_name(self, input: impl Into<String>) -> Self
pub fn domain_name(self, input: impl Into<String>) -> Self
The fully qualified domain name (FQDN).
sourcepub fn set_domain_name(self, input: Option<String>) -> Self
pub fn set_domain_name(self, input: Option<String>) -> Self
The fully qualified domain name (FQDN).
sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
The name to display.
sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
The name to display.
sourcepub fn acm_certificate_arn(self, input: impl Into<String>) -> Self
pub fn acm_certificate_arn(self, input: impl Into<String>) -> Self
The ARN of an issued ACM certificate that is valid for the domain being associated.
sourcepub fn set_acm_certificate_arn(self, input: Option<String>) -> Self
pub fn set_acm_certificate_arn(self, input: Option<String>) -> Self
The ARN of an issued ACM certificate that is valid for the domain being associated.
sourcepub fn build(self) -> Result<AssociateDomainInput, BuildError>
pub fn build(self) -> Result<AssociateDomainInput, BuildError>
Consumes the builder and constructs a AssociateDomainInput.
Examples found in repository?
src/client.rs (line 572)
560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602
pub async fn customize(
self,
) -> std::result::Result<
crate::operation::customize::CustomizableOperation<
crate::operation::AssociateDomain,
aws_http::retry::AwsResponseRetryClassifier,
>,
aws_smithy_http::result::SdkError<crate::error::AssociateDomainError>,
> {
let handle = self.handle.clone();
let operation = self
.inner
.build()
.map_err(aws_smithy_http::result::SdkError::construction_failure)?
.make_operation(&handle.conf)
.await
.map_err(aws_smithy_http::result::SdkError::construction_failure)?;
Ok(crate::operation::customize::CustomizableOperation { handle, operation })
}
/// Sends the request and returns the response.
///
/// If an error occurs, an `SdkError` will be returned with additional details that
/// can be matched against.
///
/// By default, any retryable failures will be retried twice. Retry behavior
/// is configurable with the [RetryConfig](aws_smithy_types::retry::RetryConfig), which can be
/// set when configuring the client.
pub async fn send(
self,
) -> std::result::Result<
crate::output::AssociateDomainOutput,
aws_smithy_http::result::SdkError<crate::error::AssociateDomainError>,
> {
let op = self
.inner
.build()
.map_err(aws_smithy_http::result::SdkError::construction_failure)?
.make_operation(&self.handle.conf)
.await
.map_err(aws_smithy_http::result::SdkError::construction_failure)?;
self.handle.client.call(op).await
}