Struct aws_sdk_worklink::input::associate_domain_input::Builder
source · [−]pub struct Builder { /* private fields */ }Expand description
A builder for AssociateDomainInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn fleet_arn(self, input: impl Into<String>) -> Self
pub fn fleet_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the fleet.
sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the fleet.
sourcepub fn domain_name(self, input: impl Into<String>) -> Self
pub fn domain_name(self, input: impl Into<String>) -> Self
The fully qualified domain name (FQDN).
sourcepub fn set_domain_name(self, input: Option<String>) -> Self
pub fn set_domain_name(self, input: Option<String>) -> Self
The fully qualified domain name (FQDN).
sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
The name to display.
sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
The name to display.
sourcepub fn acm_certificate_arn(self, input: impl Into<String>) -> Self
pub fn acm_certificate_arn(self, input: impl Into<String>) -> Self
The ARN of an issued ACM certificate that is valid for the domain being associated.
sourcepub fn set_acm_certificate_arn(self, input: Option<String>) -> Self
pub fn set_acm_certificate_arn(self, input: Option<String>) -> Self
The ARN of an issued ACM certificate that is valid for the domain being associated.
sourcepub fn build(self) -> Result<AssociateDomainInput, BuildError>
pub fn build(self) -> Result<AssociateDomainInput, BuildError>
Consumes the builder and constructs a AssociateDomainInput.