Struct aws_sdk_worklink::input::associate_domain_input::Builder
source · [−]#[non_exhaustive]pub struct Builder { /* private fields */ }Expand description
A builder for AssociateDomainInput
Implementations
The Amazon Resource Name (ARN) of the fleet.
The Amazon Resource Name (ARN) of the fleet.
The fully qualified domain name (FQDN).
The fully qualified domain name (FQDN).
The name to display.
The name to display.
The ARN of an issued ACM certificate that is valid for the domain being associated.
The ARN of an issued ACM certificate that is valid for the domain being associated.
Consumes the builder and constructs a AssociateDomainInput