pub struct Builder { /* private fields */ }
A builder for CreateFleetInput.

Implementations

A unique name for the fleet.

Examples found in repository?
src/client.rs (line 920)
919
920
921
922
        pub fn fleet_name(mut self, input: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.fleet_name(input.into());
            self
        }

A unique name for the fleet.

Examples found in repository?
src/client.rs (line 925)
924
925
926
927
        pub fn set_fleet_name(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_fleet_name(input);
            self
        }

The fleet name to display.

Examples found in repository?
src/client.rs (line 930)
929
930
931
932
        pub fn display_name(mut self, input: impl Into<std::string::String>) -> Self {
            self.inner = self.inner.display_name(input.into());
            self
        }

The fleet name to display.

Examples found in repository?
src/client.rs (line 935)
934
935
936
937
        pub fn set_display_name(mut self, input: std::option::Option<std::string::String>) -> Self {
            self.inner = self.inner.set_display_name(input);
            self
        }

The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.

Examples found in repository?
src/client.rs (line 940)
939
940
941
942
        pub fn optimize_for_end_user_location(mut self, input: bool) -> Self {
            self.inner = self.inner.optimize_for_end_user_location(input);
            self
        }

The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.

Examples found in repository?
src/client.rs (line 948)
944
945
946
947
948
949
950
        pub fn set_optimize_for_end_user_location(
            mut self,
            input: std::option::Option<bool>,
        ) -> Self {
            self.inner = self.inner.set_optimize_for_end_user_location(input);
            self
        }

Adds a key-value pair to tags.

To override the contents of this collection use set_tags.

The tags to add to the resource. A tag is a key-value pair.

Examples found in repository?
src/client.rs (line 961)
956
957
958
959
960
961
962
963
        pub fn tags(
            mut self,
            k: impl Into<std::string::String>,
            v: impl Into<std::string::String>,
        ) -> Self {
            self.inner = self.inner.tags(k.into(), v.into());
            self
        }

The tags to add to the resource. A tag is a key-value pair.

Examples found in repository?
src/client.rs (line 971)
965
966
967
968
969
970
971
972
973
        pub fn set_tags(
            mut self,
            input: std::option::Option<
                std::collections::HashMap<std::string::String, std::string::String>,
            >,
        ) -> Self {
            self.inner = self.inner.set_tags(input);
            self
        }

Consumes the builder and constructs a CreateFleetInput.

Examples found in repository?
src/client.rs (line 887)
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
        pub async fn customize(
            self,
        ) -> std::result::Result<
            crate::operation::customize::CustomizableOperation<
                crate::operation::CreateFleet,
                aws_http::retry::AwsResponseRetryClassifier,
            >,
            aws_smithy_http::result::SdkError<crate::error::CreateFleetError>,
        > {
            let handle = self.handle.clone();
            let operation = self
                .inner
                .build()
                .map_err(aws_smithy_http::result::SdkError::construction_failure)?
                .make_operation(&handle.conf)
                .await
                .map_err(aws_smithy_http::result::SdkError::construction_failure)?;
            Ok(crate::operation::customize::CustomizableOperation { handle, operation })
        }

        /// Sends the request and returns the response.
        ///
        /// If an error occurs, an `SdkError` will be returned with additional details that
        /// can be matched against.
        ///
        /// By default, any retryable failures will be retried twice. Retry behavior
        /// is configurable with the [RetryConfig](aws_smithy_types::retry::RetryConfig), which can be
        /// set when configuring the client.
        pub async fn send(
            self,
        ) -> std::result::Result<
            crate::output::CreateFleetOutput,
            aws_smithy_http::result::SdkError<crate::error::CreateFleetError>,
        > {
            let op = self
                .inner
                .build()
                .map_err(aws_smithy_http::result::SdkError::construction_failure)?
                .make_operation(&self.handle.conf)
                .await
                .map_err(aws_smithy_http::result::SdkError::construction_failure)?;
            self.handle.client.call(op).await
        }