Struct aws_sdk_worklink::input::create_fleet_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateFleetInput
Implementations
A unique name for the fleet.
A unique name for the fleet.
The fleet name to display.
The fleet name to display.
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
Adds a key-value pair to tags.
To override the contents of this collection use set_tags.
The tags to add to the resource. A tag is a key-value pair.
The tags to add to the resource. A tag is a key-value pair.
Consumes the builder and constructs a CreateFleetInput