Struct aws_sdk_worklink::input::AssociateDomainInput
source · [−]#[non_exhaustive]pub struct AssociateDomainInput {
pub fleet_arn: Option<String>,
pub domain_name: Option<String>,
pub display_name: Option<String>,
pub acm_certificate_arn: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fleet_arn: Option<String>The Amazon Resource Name (ARN) of the fleet.
domain_name: Option<String>The fully qualified domain name (FQDN).
display_name: Option<String>The name to display.
acm_certificate_arn: Option<String>The ARN of an issued ACM certificate that is valid for the domain being associated.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<AssociateDomain, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<AssociateDomain, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<AssociateDomain>
Creates a new builder-style object to manufacture AssociateDomainInput
The fully qualified domain name (FQDN).
The name to display.
The ARN of an issued ACM certificate that is valid for the domain being associated.