Struct aws_sdk_worklink::input::CreateFleetInput
source · [−]#[non_exhaustive]pub struct CreateFleetInput {
pub fleet_name: Option<String>,
pub display_name: Option<String>,
pub optimize_for_end_user_location: Option<bool>,
pub tags: Option<HashMap<String, String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.fleet_name: Option<String>A unique name for the fleet.
display_name: Option<String>The fleet name to display.
optimize_for_end_user_location: Option<bool>The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
The tags to add to the resource. A tag is a key-value pair.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateFleet, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateFleet, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<CreateFleet>
Creates a new builder-style object to manufacture CreateFleetInput
A unique name for the fleet.
The fleet name to display.
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
The tags to add to the resource. A tag is a key-value pair.