#[non_exhaustive]pub struct AssociateDomainInputBuilder { /* private fields */ }Expand description
A builder for AssociateDomainInput.
Implementations
sourceimpl AssociateDomainInputBuilder
impl AssociateDomainInputBuilder
sourcepub fn fleet_arn(self, input: impl Into<String>) -> Self
pub fn fleet_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the fleet.
This field is required.sourcepub fn set_fleet_arn(self, input: Option<String>) -> Self
pub fn set_fleet_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the fleet.
sourcepub fn get_fleet_arn(&self) -> &Option<String>
pub fn get_fleet_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the fleet.
sourcepub fn domain_name(self, input: impl Into<String>) -> Self
pub fn domain_name(self, input: impl Into<String>) -> Self
The fully qualified domain name (FQDN).
This field is required.sourcepub fn set_domain_name(self, input: Option<String>) -> Self
pub fn set_domain_name(self, input: Option<String>) -> Self
The fully qualified domain name (FQDN).
sourcepub fn get_domain_name(&self) -> &Option<String>
pub fn get_domain_name(&self) -> &Option<String>
The fully qualified domain name (FQDN).
sourcepub fn display_name(self, input: impl Into<String>) -> Self
pub fn display_name(self, input: impl Into<String>) -> Self
The name to display.
sourcepub fn set_display_name(self, input: Option<String>) -> Self
pub fn set_display_name(self, input: Option<String>) -> Self
The name to display.
sourcepub fn get_display_name(&self) -> &Option<String>
pub fn get_display_name(&self) -> &Option<String>
The name to display.
sourcepub fn acm_certificate_arn(self, input: impl Into<String>) -> Self
pub fn acm_certificate_arn(self, input: impl Into<String>) -> Self
The ARN of an issued ACM certificate that is valid for the domain being associated.
This field is required.sourcepub fn set_acm_certificate_arn(self, input: Option<String>) -> Self
pub fn set_acm_certificate_arn(self, input: Option<String>) -> Self
The ARN of an issued ACM certificate that is valid for the domain being associated.
sourcepub fn get_acm_certificate_arn(&self) -> &Option<String>
pub fn get_acm_certificate_arn(&self) -> &Option<String>
The ARN of an issued ACM certificate that is valid for the domain being associated.
sourcepub fn build(self) -> Result<AssociateDomainInput, BuildError>
pub fn build(self) -> Result<AssociateDomainInput, BuildError>
Consumes the builder and constructs a AssociateDomainInput.
sourceimpl AssociateDomainInputBuilder
impl AssociateDomainInputBuilder
sourcepub async fn send_with(
self,
client: &Client
) -> Result<AssociateDomainOutput, SdkError<AssociateDomainError, HttpResponse>>
pub async fn send_with( self, client: &Client ) -> Result<AssociateDomainOutput, SdkError<AssociateDomainError, HttpResponse>>
Sends a request with this input using the given client.