Struct aws_sdk_worklink::output::DescribeDeviceOutput
source · [−]#[non_exhaustive]pub struct DescribeDeviceOutput { /* private fields */ }Implementations
sourceimpl DescribeDeviceOutput
impl DescribeDeviceOutput
sourcepub fn status(&self) -> Option<&DeviceStatus>
pub fn status(&self) -> Option<&DeviceStatus>
The current state of the device.
sourcepub fn manufacturer(&self) -> Option<&str>
pub fn manufacturer(&self) -> Option<&str>
The manufacturer of the device.
sourcepub fn operating_system(&self) -> Option<&str>
pub fn operating_system(&self) -> Option<&str>
The operating system of the device.
sourcepub fn operating_system_version(&self) -> Option<&str>
pub fn operating_system_version(&self) -> Option<&str>
The operating system version of the device.
sourcepub fn patch_level(&self) -> Option<&str>
pub fn patch_level(&self) -> Option<&str>
The operating system patch level of the device.
sourcepub fn first_accessed_time(&self) -> Option<&DateTime>
pub fn first_accessed_time(&self) -> Option<&DateTime>
The date that the device first signed in to Amazon WorkLink.
sourcepub fn last_accessed_time(&self) -> Option<&DateTime>
pub fn last_accessed_time(&self) -> Option<&DateTime>
The date that the device last accessed Amazon WorkLink.
sourceimpl DescribeDeviceOutput
impl DescribeDeviceOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeDeviceOutput.