Struct aws_sdk_worklink::output::DescribeDeviceOutput [−][src]
#[non_exhaustive]pub struct DescribeDeviceOutput {
pub status: Option<DeviceStatus>,
pub model: Option<String>,
pub manufacturer: Option<String>,
pub operating_system: Option<String>,
pub operating_system_version: Option<String>,
pub patch_level: Option<String>,
pub first_accessed_time: Option<DateTime>,
pub last_accessed_time: Option<DateTime>,
pub username: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.status: Option<DeviceStatus>The current state of the device.
model: Option<String>The model of the device.
manufacturer: Option<String>The manufacturer of the device.
operating_system: Option<String>The operating system of the device.
operating_system_version: Option<String>The operating system version of the device.
patch_level: Option<String>The operating system patch level of the device.
first_accessed_time: Option<DateTime>The date that the device first signed in to Amazon WorkLink.
last_accessed_time: Option<DateTime>The date that the device last accessed Amazon WorkLink.
username: Option<String>The user name associated with the device.
Implementations
The current state of the device.
The manufacturer of the device.
The operating system of the device.
The operating system version of the device.
The operating system patch level of the device.
The date that the device first signed in to Amazon WorkLink.
The date that the device last accessed Amazon WorkLink.
Creates a new builder-style object to manufacture DescribeDeviceOutput