#[non_exhaustive]pub struct DescribeFleetMetadataOutput { /* private fields */ }Implementations
sourceimpl DescribeFleetMetadataOutput
impl DescribeFleetMetadataOutput
sourcepub fn created_time(&self) -> Option<&DateTime>
pub fn created_time(&self) -> Option<&DateTime>
The time that the fleet was created.
sourcepub fn last_updated_time(&self) -> Option<&DateTime>
pub fn last_updated_time(&self) -> Option<&DateTime>
The time that the fleet was last updated.
sourcepub fn fleet_name(&self) -> Option<&str>
pub fn fleet_name(&self) -> Option<&str>
The name of the fleet.
sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The name to display.
sourcepub fn optimize_for_end_user_location(&self) -> Option<bool>
pub fn optimize_for_end_user_location(&self) -> Option<bool>
The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.
sourcepub fn company_code(&self) -> Option<&str>
pub fn company_code(&self) -> Option<&str>
The identifier used by users to sign in to the Amazon WorkLink app.
sourcepub fn fleet_status(&self) -> Option<&FleetStatus>
pub fn fleet_status(&self) -> Option<&FleetStatus>
The current state of the fleet.
The tags attached to the resource. A tag is a key-value pair.
sourceimpl DescribeFleetMetadataOutput
impl DescribeFleetMetadataOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture DescribeFleetMetadataOutput.