#[non_exhaustive]
pub struct DescribeFleetMetadataOutput { pub created_time: Option<DateTime>, pub last_updated_time: Option<DateTime>, pub fleet_name: Option<String>, pub display_name: Option<String>, pub optimize_for_end_user_location: Option<bool>, pub company_code: Option<String>, pub fleet_status: Option<FleetStatus>, pub tags: Option<HashMap<String, String>>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
created_time: Option<DateTime>

The time that the fleet was created.

last_updated_time: Option<DateTime>

The time that the fleet was last updated.

fleet_name: Option<String>

The name of the fleet.

display_name: Option<String>

The name to display.

optimize_for_end_user_location: Option<bool>

The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.

company_code: Option<String>

The identifier used by users to sign in to the Amazon WorkLink app.

fleet_status: Option<FleetStatus>

The current state of the fleet.

tags: Option<HashMap<String, String>>

The tags attached to the resource. A tag is a key-value pair.

Implementations

The time that the fleet was created.

The time that the fleet was last updated.

The name of the fleet.

The name to display.

The option to optimize for better performance by routing traffic through the closest AWS Region to users, which may be outside of your home Region.

The identifier used by users to sign in to the Amazon WorkLink app.

The current state of the fleet.

The tags attached to the resource. A tag is a key-value pair.

Creates a new builder-style object to manufacture DescribeFleetMetadataOutput