Struct aws_sdk_worklink::output::ListFleetsOutput
source · [−]#[non_exhaustive]pub struct ListFleetsOutput { /* private fields */ }Implementations
sourceimpl ListFleetsOutput
impl ListFleetsOutput
sourcepub fn fleet_summary_list(&self) -> Option<&[FleetSummary]>
pub fn fleet_summary_list(&self) -> Option<&[FleetSummary]>
The summary list of the fleets.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
The pagination token used to retrieve the next page of results for this operation. If there are no more pages, this value is null.
sourceimpl ListFleetsOutput
impl ListFleetsOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture ListFleetsOutput.